/* pastebin_dialog.c generated by valac 0.56.19, the Vala compiler
 * generated from pastebin_dialog.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; tab-width: 4 -*-*/

#include "pastebin.h"
#include "codecore.h"
#include <gtk/gtk.h>
#include <granite.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib-object.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	SCRATCH_DIALOGS_PASTE_BIN_DIALOG_0_PROPERTY,
	SCRATCH_DIALOGS_PASTE_BIN_DIALOG_DOC_PROPERTY,
	SCRATCH_DIALOGS_PASTE_BIN_DIALOG_NUM_PROPERTIES
};
static GParamSpec* scratch_dialogs_paste_bin_dialog_properties[SCRATCH_DIALOGS_PASTE_BIN_DIALOG_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block1Data Block1Data;

struct _ScratchDialogsPasteBinDialogPrivate {
	ScratchServicesDocument* _doc;
	GtkButton* close_button;
	GtkButton* upload_button;
	GtkEntry* name_entry;
	GtkComboBoxText* expiry_combo;
	GtkCheckButton* private_check;
	GtkComboBoxText* format_combo;
	GraniteDialog* format_dialog;
	GtkStack* stack;
	GtkListBox* languages_listbox;
};

struct _Block1Data {
	int _ref_count_;
	ScratchDialogsPasteBinDialog* self;
	GtkSpinner* spinner;
};

static gint ScratchDialogsPasteBinDialog_private_offset;
static gpointer scratch_dialogs_paste_bin_dialog_parent_class = NULL;
static GType scratch_dialogs_paste_bin_dialog_type_id = 0;

static void scratch_dialogs_paste_bin_dialog_format_button_clicked (ScratchDialogsPasteBinDialog* self);
static void scratch_dialogs_paste_bin_dialog_select_button_clicked (ScratchDialogsPasteBinDialog* self);
static void _scratch_dialogs_paste_bin_dialog_select_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                 gpointer self);
static void __lambda4_ (ScratchDialogsPasteBinDialog* self);
static void ___lambda4__gtk_button_clicked (GtkButton* _sender,
                                     gpointer self);
static void scratch_dialogs_paste_bin_dialog_read_settings (ScratchDialogsPasteBinDialog* self);
static void scratch_dialogs_paste_bin_dialog_write_settings (ScratchDialogsPasteBinDialog* self);
static void scratch_dialogs_paste_bin_dialog_upload_button_clicked (ScratchDialogsPasteBinDialog* self);
static gboolean scratch_dialogs_paste_bin_dialog_submit_paste (ScratchDialogsPasteBinDialog* self,
                                                        gchar** link);
static void scratch_dialogs_paste_bin_dialog_populate_expiry_combo (ScratchDialogsPasteBinDialog* self);
static GObject * scratch_dialogs_paste_bin_dialog_constructor (GType type,
                                                        guint n_construct_properties,
                                                        GObjectConstructParam * construct_properties);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void _scratch_dialogs_paste_bin_dialog_format_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                 gpointer self);
static void _scratch_dialogs_paste_bin_dialog___lambda5_ (Block1Data* _data1_);
static void __scratch_dialogs_paste_bin_dialog___lambda5__gtk_button_clicked (GtkButton* _sender,
                                                                       gpointer self);
static void _scratch_dialogs_paste_bin_dialog___lambda6_ (ScratchDialogsPasteBinDialog* self);
static void __scratch_dialogs_paste_bin_dialog___lambda6__gtk_button_clicked (GtkButton* _sender,
                                                                       gpointer self);
static void _scratch_dialogs_paste_bin_dialog___lambda7_ (ScratchDialogsPasteBinDialog* self);
static void __scratch_dialogs_paste_bin_dialog___lambda7__gtk_widget_destroy (GtkWidget* _sender,
                                                                       gpointer self);
static void scratch_dialogs_paste_bin_dialog_finalize (GObject * obj);
static void _vala_scratch_dialogs_paste_bin_dialog_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec);
static void _vala_scratch_dialogs_paste_bin_dialog_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
scratch_dialogs_paste_bin_dialog_get_instance_private (ScratchDialogsPasteBinDialog* self)
{
	return G_STRUCT_MEMBER_P (self, ScratchDialogsPasteBinDialog_private_offset);
}

ScratchDialogsPasteBinDialog*
scratch_dialogs_paste_bin_dialog_construct (GType object_type,
                                            GtkWindow* parent,
                                            ScratchServicesDocument* doc)
{
	ScratchDialogsPasteBinDialog * self = NULL;
	g_return_val_if_fail (doc != NULL, NULL);
	self = (ScratchDialogsPasteBinDialog*) g_object_new (object_type, "resizable", FALSE, "doc", doc, "transient-for", parent, "title", _ ("Upload to Pastebin"), NULL);
	return self;
}

ScratchDialogsPasteBinDialog*
scratch_dialogs_paste_bin_dialog_new (GtkWindow* parent,
                                      ScratchServicesDocument* doc)
{
	return scratch_dialogs_paste_bin_dialog_construct (SCRATCH_DIALOGS_TYPE_PASTE_BIN_DIALOG, parent, doc);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_scratch_dialogs_paste_bin_dialog_select_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                            gpointer self)
{
	scratch_dialogs_paste_bin_dialog_select_button_clicked ((ScratchDialogsPasteBinDialog*) self);
}

static void
__lambda4_ (ScratchDialogsPasteBinDialog* self)
{
	GraniteDialog* _tmp0_;
	_tmp0_ = self->priv->format_dialog;
	gtk_widget_destroy ((GtkWidget*) _tmp0_);
}

static void
___lambda4__gtk_button_clicked (GtkButton* _sender,
                                gpointer self)
{
	__lambda4_ ((ScratchDialogsPasteBinDialog*) self);
}

static void
scratch_dialogs_paste_bin_dialog_format_button_clicked (ScratchDialogsPasteBinDialog* self)
{
	gchar* _tmp0_;
	GraniteDialog* _tmp1_ = NULL;
	GraniteDialog* _tmp2_;
	GtkListBox* _tmp3_ = NULL;
	GtkScrolledWindow* languages_scrolled = NULL;
	GtkScrolledWindow* _tmp13_ = NULL;
	GtkListBox* _tmp14_;
	GtkButton* cancel_button = NULL;
	GraniteDialog* _tmp15_;
	GtkWidget* _tmp16_;
	GtkButton* _tmp17_;
	GtkButton* select_button = NULL;
	GraniteDialog* _tmp18_;
	GtkWidget* _tmp19_;
	GtkButton* _tmp20_;
	GtkStyleContext* _tmp21_;
	GtkFrame* frame = NULL;
	GtkFrame* _tmp22_ = NULL;
	GraniteDialog* _tmp23_;
	GtkBox* _tmp24_;
	GraniteDialog* _tmp25_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (_ ("Available Formats"));
	_tmp1_ = granite_dialog_new ();
	gtk_window_set_resizable ((GtkWindow*) _tmp1_, FALSE);
	gtk_window_set_title ((GtkWindow*) _tmp1_, _tmp0_);
	_g_free0 (_tmp0_);
	g_object_ref_sink (_tmp1_);
	_g_object_unref0 (self->priv->format_dialog);
	self->priv->format_dialog = _tmp1_;
	_tmp2_ = self->priv->format_dialog;
	gtk_window_set_default_size ((GtkWindow*) _tmp2_, 220, 300);
	_tmp3_ = (GtkListBox*) gtk_list_box_new ();
	gtk_list_box_set_selection_mode (_tmp3_, GTK_SELECTION_SINGLE);
	g_object_ref_sink (_tmp3_);
	_g_object_unref0 (self->priv->languages_listbox);
	self->priv->languages_listbox = _tmp3_;
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp4_ = FALSE;
			_tmp4_ = TRUE;
			while (TRUE) {
				gchar** _tmp6_;
				gint _tmp6__length1;
				gint _tmp6__length2;
				gint _tmp7_;
				GtkLabel* label = NULL;
				gchar** _tmp8_;
				gint _tmp8__length1;
				gint _tmp8__length2;
				const gchar* _tmp9_;
				GtkLabel* _tmp10_ = NULL;
				GtkListBox* _tmp11_;
				GtkLabel* _tmp12_;
				if (!_tmp4_) {
					gint _tmp5_;
					_tmp5_ = i;
					i = _tmp5_ + 1;
				}
				_tmp4_ = FALSE;
				_tmp6_ = self->languages;
				_tmp6__length1 = self->languages_length1;
				_tmp6__length2 = self->languages_length2;
				_tmp7_ = _tmp6__length1;
				if (!(i < _tmp7_)) {
					break;
				}
				_tmp8_ = self->languages;
				_tmp8__length1 = self->languages_length1;
				_tmp8__length2 = self->languages_length2;
				_tmp9_ = _tmp8_[(i * _tmp8__length2) + 2];
				_tmp10_ = (GtkLabel*) gtk_label_new (_tmp9_);
				gtk_widget_set_halign ((GtkWidget*) _tmp10_, GTK_ALIGN_START);
				g_object_set ((GtkWidget*) _tmp10_, "margin", 6, NULL);
				g_object_ref_sink (_tmp10_);
				label = _tmp10_;
				_tmp11_ = self->priv->languages_listbox;
				_tmp12_ = label;
				gtk_container_add ((GtkContainer*) _tmp11_, (GtkWidget*) _tmp12_);
				_g_object_unref0 (label);
			}
		}
	}
	_tmp13_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
	g_object_set (_tmp13_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
	g_object_set ((GtkWidget*) _tmp13_, "height-request", 250, NULL);
	g_object_set ((GtkWidget*) _tmp13_, "expand", TRUE, NULL);
	g_object_ref_sink (_tmp13_);
	languages_scrolled = _tmp13_;
	_tmp14_ = self->priv->languages_listbox;
	gtk_container_add ((GtkContainer*) languages_scrolled, (GtkWidget*) _tmp14_);
	_tmp15_ = self->priv->format_dialog;
	_tmp16_ = gtk_dialog_add_button ((GtkDialog*) _tmp15_, _ ("Cancel"), (gint) GTK_RESPONSE_CANCEL);
	_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_button_get_type (), GtkButton));
	cancel_button = _tmp17_;
	_tmp18_ = self->priv->format_dialog;
	_tmp19_ = gtk_dialog_add_button ((GtkDialog*) _tmp18_, _ ("Select Format"), (gint) GTK_RESPONSE_OK);
	_tmp20_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_button_get_type (), GtkButton));
	select_button = _tmp20_;
	_tmp21_ = gtk_widget_get_style_context ((GtkWidget*) select_button);
	gtk_style_context_add_class (_tmp21_, GTK_STYLE_CLASS_SUGGESTED_ACTION);
	g_signal_connect_object (select_button, "clicked", (GCallback) _scratch_dialogs_paste_bin_dialog_select_button_clicked_gtk_button_clicked, self, 0);
	_tmp22_ = (GtkFrame*) gtk_frame_new (NULL);
	g_object_set ((GtkWidget*) _tmp22_, "margin", 12, NULL);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp22_, 0);
	g_object_ref_sink (_tmp22_);
	frame = _tmp22_;
	gtk_container_add ((GtkContainer*) frame, (GtkWidget*) languages_scrolled);
	_tmp23_ = self->priv->format_dialog;
	_tmp24_ = gtk_dialog_get_content_area ((GtkDialog*) _tmp23_);
	gtk_container_add ((GtkContainer*) _tmp24_, (GtkWidget*) frame);
	_tmp25_ = self->priv->format_dialog;
	gtk_widget_show_all ((GtkWidget*) _tmp25_);
	g_signal_connect_object (cancel_button, "clicked", (GCallback) ___lambda4__gtk_button_clicked, self, 0);
	_g_object_unref0 (frame);
	_g_object_unref0 (select_button);
	_g_object_unref0 (cancel_button);
	_g_object_unref0 (languages_scrolled);
}

static void
scratch_dialogs_paste_bin_dialog_select_button_clicked (ScratchDialogsPasteBinDialog* self)
{
	GtkListBoxRow* selection = NULL;
	GtkListBox* _tmp0_;
	GtkListBoxRow* _tmp1_;
	GtkListBoxRow* _tmp2_;
	GtkListBoxRow* _tmp3_;
	GraniteDialog* _tmp27_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->languages_listbox;
	_tmp1_ = gtk_list_box_get_selected_row (_tmp0_);
	_tmp2_ = _g_object_ref0 (_tmp1_);
	selection = _tmp2_;
	_tmp3_ = selection;
	if (_tmp3_ != NULL) {
		GtkLabel* label = NULL;
		GtkListBoxRow* _tmp4_;
		GtkWidget* _tmp5_;
		GtkLabel* _tmp6_;
		gchar* lang_name = NULL;
		GtkLabel* _tmp7_;
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* lang_code = NULL;
		gchar* _tmp11_;
		_tmp4_ = selection;
		_tmp5_ = gtk_bin_get_child ((GtkBin*) _tmp4_);
		_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_label_get_type (), GtkLabel));
		label = _tmp6_;
		_tmp7_ = label;
		_tmp8_ = gtk_label_get_label (_tmp7_);
		_tmp9_ = _tmp8_;
		_tmp10_ = g_strdup (_tmp9_);
		lang_name = _tmp10_;
		_tmp11_ = g_strdup ("");
		lang_code = _tmp11_;
		{
			gint i = 0;
			i = 0;
			{
				gboolean _tmp12_ = FALSE;
				_tmp12_ = TRUE;
				while (TRUE) {
					gchar** _tmp14_;
					gint _tmp14__length1;
					gint _tmp14__length2;
					gint _tmp15_;
					gchar** _tmp16_;
					gint _tmp16__length1;
					gint _tmp16__length2;
					const gchar* _tmp17_;
					const gchar* _tmp18_;
					if (!_tmp12_) {
						gint _tmp13_;
						_tmp13_ = i;
						i = _tmp13_ + 1;
					}
					_tmp12_ = FALSE;
					_tmp14_ = self->languages;
					_tmp14__length1 = self->languages_length1;
					_tmp14__length2 = self->languages_length2;
					_tmp15_ = _tmp14__length1;
					if (!(i < _tmp15_)) {
						break;
					}
					_tmp16_ = self->languages;
					_tmp16__length1 = self->languages_length1;
					_tmp16__length2 = self->languages_length2;
					_tmp17_ = _tmp16_[(i * _tmp16__length2) + 2];
					_tmp18_ = lang_name;
					if (g_strcmp0 (_tmp17_, _tmp18_) == 0) {
						gchar** _tmp19_;
						gint _tmp19__length1;
						gint _tmp19__length2;
						const gchar* _tmp20_;
						gchar* _tmp21_;
						GtkComboBoxText* _tmp22_;
						const gchar* _tmp23_;
						const gchar* _tmp24_;
						GtkComboBoxText* _tmp25_;
						const gchar* _tmp26_;
						_tmp19_ = self->languages;
						_tmp19__length1 = self->languages_length1;
						_tmp19__length2 = self->languages_length2;
						_tmp20_ = _tmp19_[(i * _tmp19__length2) + 1];
						_tmp21_ = g_strdup (_tmp20_);
						_g_free0 (lang_code);
						lang_code = _tmp21_;
						_tmp22_ = self->priv->format_combo;
						_tmp23_ = lang_code;
						_tmp24_ = lang_name;
						gtk_combo_box_text_append (_tmp22_, _tmp23_, _tmp24_);
						_tmp25_ = self->priv->format_combo;
						_tmp26_ = lang_code;
						gtk_combo_box_set_active_id ((GtkComboBox*) _tmp25_, _tmp26_);
						break;
					}
				}
			}
		}
		_g_free0 (lang_code);
		_g_free0 (lang_name);
		_g_object_unref0 (label);
	}
	_tmp27_ = self->priv->format_dialog;
	gtk_widget_destroy ((GtkWidget*) _tmp27_);
	_g_object_unref0 (selection);
}

static void
scratch_dialogs_paste_bin_dialog_read_settings (ScratchDialogsPasteBinDialog* self)
{
	gchar* paste_name = NULL;
	ScratchServicesDocument* _tmp0_;
	gchar* _tmp1_;
	GtkEntry* _tmp2_;
	GtkComboBoxText* _tmp3_;
	GSettings* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GtkCheckButton* _tmp7_;
	GSettings* _tmp8_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_doc;
	_tmp1_ = scratch_services_document_get_basename (_tmp0_);
	paste_name = _tmp1_;
	_tmp2_ = self->priv->name_entry;
	gtk_entry_set_text (_tmp2_, paste_name);
	_tmp3_ = self->priv->expiry_combo;
	_tmp4_ = scratch_service_settings;
	_tmp5_ = g_settings_get_string (_tmp4_, "expiry-time");
	_tmp6_ = _tmp5_;
	gtk_combo_box_set_active_id ((GtkComboBox*) _tmp3_, _tmp6_);
	_g_free0 (_tmp6_);
	_tmp7_ = self->priv->private_check;
	_tmp8_ = scratch_service_settings;
	gtk_toggle_button_set_active ((GtkToggleButton*) _tmp7_, g_settings_get_boolean (_tmp8_, "set-private"));
	_g_free0 (paste_name);
}

static void
scratch_dialogs_paste_bin_dialog_write_settings (ScratchDialogsPasteBinDialog* self)
{
	GSettings* _tmp0_;
	GtkComboBoxText* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	GSettings* _tmp4_;
	GtkComboBoxText* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	GSettings* _tmp8_;
	GtkCheckButton* _tmp9_;
	gboolean _tmp10_;
	gboolean _tmp11_;
	g_return_if_fail (self != NULL);
	_tmp0_ = scratch_service_settings;
	_tmp1_ = self->priv->format_combo;
	_tmp2_ = gtk_combo_box_get_active_id ((GtkComboBox*) _tmp1_);
	_tmp3_ = _tmp2_;
	g_settings_set_string (_tmp0_, "paste-format-code", _tmp3_);
	_tmp4_ = scratch_service_settings;
	_tmp5_ = self->priv->expiry_combo;
	_tmp6_ = gtk_combo_box_get_active_id ((GtkComboBox*) _tmp5_);
	_tmp7_ = _tmp6_;
	g_settings_set_string (_tmp4_, "expiry-time", _tmp7_);
	_tmp8_ = scratch_service_settings;
	_tmp9_ = self->priv->private_check;
	_tmp10_ = gtk_toggle_button_get_active ((GtkToggleButton*) _tmp9_);
	_tmp11_ = _tmp10_;
	g_settings_set_boolean (_tmp8_, "set-private", _tmp11_);
}

static void
scratch_dialogs_paste_bin_dialog_upload_button_clicked (ScratchDialogsPasteBinDialog* self)
{
	GtkButton* _tmp0_;
	GtkButton* _tmp1_;
	gchar* link = NULL;
	gboolean submit_result = FALSE;
	gchar* _tmp2_ = NULL;
	gboolean _tmp3_;
	GtkBox* box = NULL;
	GtkBox* _tmp4_;
	GtkStack* _tmp5_;
	GtkBox* _tmp6_;
	GtkBox* _tmp15_;
	GtkStack* _tmp16_;
	GtkBox* _tmp17_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->upload_button;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, FALSE);
	_tmp1_ = self->priv->close_button;
	gtk_button_set_label (_tmp1_, _ ("Close"));
	_tmp3_ = scratch_dialogs_paste_bin_dialog_submit_paste (self, &_tmp2_);
	_g_free0 (link);
	link = _tmp2_;
	submit_result = _tmp3_;
	_tmp4_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
	g_object_ref_sink (_tmp4_);
	box = _tmp4_;
	_tmp5_ = self->priv->stack;
	_tmp6_ = box;
	gtk_container_add ((GtkContainer*) _tmp5_, (GtkWidget*) _tmp6_);
	if (submit_result) {
		GtkLinkButton* link_button = NULL;
		const gchar* _tmp7_;
		GtkLinkButton* _tmp8_;
		GtkBox* _tmp9_;
		GtkLinkButton* _tmp10_;
		_tmp7_ = link;
		_tmp8_ = (GtkLinkButton*) gtk_link_button_new (_tmp7_);
		g_object_ref_sink (_tmp8_);
		link_button = _tmp8_;
		_tmp9_ = box;
		_tmp10_ = link_button;
		gtk_box_pack_start (_tmp9_, (GtkWidget*) _tmp10_, FALSE, TRUE, (guint) 25);
		_g_object_unref0 (link_button);
	} else {
		GtkLabel* err_label = NULL;
		const gchar* _tmp11_;
		GtkLabel* _tmp12_;
		GtkBox* _tmp13_;
		GtkLabel* _tmp14_;
		_tmp11_ = link;
		_tmp12_ = (GtkLabel*) gtk_label_new (_tmp11_);
		g_object_ref_sink (_tmp12_);
		err_label = _tmp12_;
		_tmp13_ = box;
		_tmp14_ = err_label;
		gtk_box_pack_start (_tmp13_, (GtkWidget*) _tmp14_, FALSE, TRUE, (guint) 0);
		_g_object_unref0 (err_label);
	}
	_tmp15_ = box;
	gtk_widget_show_all ((GtkWidget*) _tmp15_);
	_tmp16_ = self->priv->stack;
	_tmp17_ = box;
	gtk_stack_set_visible_child (_tmp16_, (GtkWidget*) _tmp17_);
	_g_object_unref0 (box);
	_g_free0 (link);
}

static gboolean
scratch_dialogs_paste_bin_dialog_submit_paste (ScratchDialogsPasteBinDialog* self,
                                               gchar** link)
{
	gchar* _vala_link = NULL;
	gchar* paste_code = NULL;
	ScratchServicesDocument* _tmp0_;
	gchar* _tmp1_;
	gchar* paste_name = NULL;
	GtkEntry* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* paste_format = NULL;
	GtkComboBoxText* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	const gchar* _tmp9_ = NULL;
	GtkCheckButton* _tmp10_;
	gchar* paste_private = NULL;
	gchar* _tmp11_;
	gchar* paste_expire_date = NULL;
	GtkComboBoxText* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_ = NULL;
	gboolean _tmp19_;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->_doc;
	_tmp1_ = scratch_services_document_get_text (_tmp0_);
	paste_code = _tmp1_;
	_tmp2_ = self->priv->name_entry;
	_tmp3_ = gtk_entry_get_text (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = g_strdup (_tmp4_);
	paste_name = _tmp5_;
	_tmp6_ = self->priv->format_combo;
	_tmp7_ = gtk_combo_box_get_active_id ((GtkComboBox*) _tmp6_);
	_tmp8_ = g_strdup (_tmp7_);
	paste_format = _tmp8_;
	_tmp10_ = self->priv->private_check;
	if (gtk_toggle_button_get_active ((GtkToggleButton*) _tmp10_) == TRUE) {
		_tmp9_ = SCRATCH_SERVICES_PASTE_BIN_PRIVATE;
	} else {
		_tmp9_ = SCRATCH_SERVICES_PASTE_BIN_PUBLIC;
	}
	_tmp11_ = g_strdup (_tmp9_);
	paste_private = _tmp11_;
	_tmp12_ = self->priv->expiry_combo;
	_tmp13_ = gtk_combo_box_get_active_id ((GtkComboBox*) _tmp12_);
	_tmp14_ = g_strdup (_tmp13_);
	paste_expire_date = _tmp14_;
	_tmp15_ = paste_code;
	_tmp16_ = paste_name;
	_tmp17_ = paste_format;
	_tmp19_ = scratch_services_paste_bin_submit (&_tmp18_, _tmp15_, _tmp16_, paste_private, paste_expire_date, _tmp17_);
	_g_free0 (_vala_link);
	_vala_link = _tmp18_;
	result = _tmp19_;
	_g_free0 (paste_expire_date);
	_g_free0 (paste_private);
	_g_free0 (paste_format);
	_g_free0 (paste_name);
	_g_free0 (paste_code);
	if (link) {
		*link = _vala_link;
	} else {
		_g_free0 (_vala_link);
	}
	return result;
}

static void
scratch_dialogs_paste_bin_dialog_populate_expiry_combo (ScratchDialogsPasteBinDialog* self)
{
	GtkComboBoxText* _tmp0_;
	GtkComboBoxText* _tmp1_;
	GtkComboBoxText* _tmp2_;
	GtkComboBoxText* _tmp3_;
	GtkComboBoxText* _tmp4_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->expiry_combo;
	gtk_combo_box_text_append (_tmp0_, SCRATCH_SERVICES_PASTE_BIN_NEVER, _ ("Never"));
	_tmp1_ = self->priv->expiry_combo;
	gtk_combo_box_text_append (_tmp1_, SCRATCH_SERVICES_PASTE_BIN_TEN_MINUTES, _ ("Ten minutes"));
	_tmp2_ = self->priv->expiry_combo;
	gtk_combo_box_text_append (_tmp2_, SCRATCH_SERVICES_PASTE_BIN_HOUR, _ ("One hour"));
	_tmp3_ = self->priv->expiry_combo;
	gtk_combo_box_text_append (_tmp3_, SCRATCH_SERVICES_PASTE_BIN_DAY, _ ("One day"));
	_tmp4_ = self->priv->expiry_combo;
	gtk_combo_box_text_append (_tmp4_, SCRATCH_SERVICES_PASTE_BIN_MONTH, _ ("One month"));
}

ScratchServicesDocument*
scratch_dialogs_paste_bin_dialog_get_doc (ScratchDialogsPasteBinDialog* self)
{
	ScratchServicesDocument* result;
	ScratchServicesDocument* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_doc;
	result = _tmp0_;
	return result;
}

static void
scratch_dialogs_paste_bin_dialog_set_doc (ScratchDialogsPasteBinDialog* self,
                                          ScratchServicesDocument* value)
{
	ScratchServicesDocument* old_value;
	g_return_if_fail (self != NULL);
	old_value = scratch_dialogs_paste_bin_dialog_get_doc (self);
	if (old_value != value) {
		ScratchServicesDocument* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_doc);
		self->priv->_doc = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, scratch_dialogs_paste_bin_dialog_properties[SCRATCH_DIALOGS_PASTE_BIN_DIALOG_DOC_PROPERTY]);
	}
}

static Block1Data*
block1_data_ref (Block1Data* _data1_)
{
	g_atomic_int_inc (&_data1_->_ref_count_);
	return _data1_;
}

static void
block1_data_unref (void * _userdata_)
{
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
		ScratchDialogsPasteBinDialog* self;
		self = _data1_->self;
		_g_object_unref0 (_data1_->spinner);
		_g_object_unref0 (self);
		g_slice_free (Block1Data, _data1_);
	}
}

static void
_scratch_dialogs_paste_bin_dialog_format_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                            gpointer self)
{
	scratch_dialogs_paste_bin_dialog_format_button_clicked ((ScratchDialogsPasteBinDialog*) self);
}

static void
_scratch_dialogs_paste_bin_dialog___lambda5_ (Block1Data* _data1_)
{
	ScratchDialogsPasteBinDialog* self;
	GtkStack* _tmp0_;
	GtkSpinner* _tmp1_;
	self = _data1_->self;
	_tmp0_ = self->priv->stack;
	_tmp1_ = _data1_->spinner;
	gtk_stack_set_visible_child (_tmp0_, (GtkWidget*) _tmp1_);
	scratch_dialogs_paste_bin_dialog_upload_button_clicked (self);
}

static void
__scratch_dialogs_paste_bin_dialog___lambda5__gtk_button_clicked (GtkButton* _sender,
                                                                  gpointer self)
{
	_scratch_dialogs_paste_bin_dialog___lambda5_ (self);
}

static void
_scratch_dialogs_paste_bin_dialog___lambda6_ (ScratchDialogsPasteBinDialog* self)
{
	gtk_widget_destroy ((GtkWidget*) self);
}

static void
__scratch_dialogs_paste_bin_dialog___lambda6__gtk_button_clicked (GtkButton* _sender,
                                                                  gpointer self)
{
	_scratch_dialogs_paste_bin_dialog___lambda6_ ((ScratchDialogsPasteBinDialog*) self);
}

static void
_scratch_dialogs_paste_bin_dialog___lambda7_ (ScratchDialogsPasteBinDialog* self)
{
	scratch_dialogs_paste_bin_dialog_write_settings (self);
}

static void
__scratch_dialogs_paste_bin_dialog___lambda7__gtk_widget_destroy (GtkWidget* _sender,
                                                                  gpointer self)
{
	_scratch_dialogs_paste_bin_dialog___lambda7_ ((ScratchDialogsPasteBinDialog*) self);
}

static GObject *
scratch_dialogs_paste_bin_dialog_constructor (GType type,
                                              guint n_construct_properties,
                                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ScratchDialogsPasteBinDialog * self;
	Block1Data* _data1_;
	GtkEntry* _tmp0_ = NULL;
	GtkLabel* name_entry_l = NULL;
	GtkLabel* _tmp1_ = NULL;
	GtkLabel* format_label = NULL;
	GtkLabel* _tmp2_ = NULL;
	GtkComboBoxText* _tmp3_;
	GtkButton* format_button = NULL;
	gchar* _tmp4_;
	GtkButton* _tmp5_ = NULL;
	gchar* sel_lang = NULL;
	ScratchServicesDocument* _tmp6_;
	gchar* _tmp7_;
	GtkComboBoxText* _tmp28_;
	const gchar* _tmp29_;
	GtkLabel* expiry_combo_l = NULL;
	GtkLabel* _tmp31_ = NULL;
	GtkComboBoxText* _tmp32_;
	GtkCheckButton* _tmp33_;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp34_ = NULL;
	GtkGrid* _tmp35_;
	GtkLabel* _tmp36_;
	GtkGrid* _tmp37_;
	GtkEntry* _tmp38_;
	GtkGrid* _tmp39_;
	GtkLabel* _tmp40_;
	GtkGrid* _tmp41_;
	GtkComboBoxText* _tmp42_;
	GtkGrid* _tmp43_;
	GtkButton* _tmp44_;
	GtkGrid* _tmp45_;
	GtkLabel* _tmp46_;
	GtkGrid* _tmp47_;
	GtkComboBoxText* _tmp48_;
	GtkGrid* _tmp49_;
	GtkCheckButton* _tmp50_;
	GtkSpinner* _tmp51_ = NULL;
	GtkStack* _tmp52_ = NULL;
	GtkStack* _tmp53_;
	GtkGrid* _tmp54_;
	GtkStack* _tmp55_;
	GtkSpinner* _tmp56_;
	GtkBox* _tmp57_;
	GtkStack* _tmp58_;
	GtkWidget* _tmp59_;
	GtkButton* _tmp60_;
	GtkWidget* _tmp61_;
	GtkButton* _tmp62_;
	GtkButton* _tmp63_;
	GtkStyleContext* _tmp64_;
	GtkButton* _tmp65_;
	GtkButton* _tmp66_;
	GtkButton* _tmp67_;
	parent_class = G_OBJECT_CLASS (scratch_dialogs_paste_bin_dialog_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SCRATCH_DIALOGS_TYPE_PASTE_BIN_DIALOG, ScratchDialogsPasteBinDialog);
	_data1_ = g_slice_new0 (Block1Data);
	_data1_->_ref_count_ = 1;
	_data1_->self = g_object_ref (self);
	_tmp0_ = (GtkEntry*) gtk_entry_new ();
	gtk_widget_set_hexpand ((GtkWidget*) _tmp0_, TRUE);
	g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->priv->name_entry);
	self->priv->name_entry = _tmp0_;
	_tmp1_ = (GtkLabel*) gtk_label_new (_ ("Name:"));
	gtk_widget_set_halign ((GtkWidget*) _tmp1_, GTK_ALIGN_END);
	g_object_ref_sink (_tmp1_);
	name_entry_l = _tmp1_;
	_tmp2_ = (GtkLabel*) gtk_label_new (_ ("Format:"));
	gtk_widget_set_halign ((GtkWidget*) _tmp2_, GTK_ALIGN_END);
	g_object_ref_sink (_tmp2_);
	format_label = _tmp2_;
	_tmp3_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
	g_object_ref_sink (_tmp3_);
	_g_object_unref0 (self->priv->format_combo);
	self->priv->format_combo = _tmp3_;
	_tmp4_ = g_strdup (_ ("Choose different format"));
	_tmp5_ = (GtkButton*) gtk_button_new_from_icon_name ("view-more-horizontal-symbolic", (GtkIconSize) GTK_ICON_SIZE_BUTTON);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp5_, _tmp4_);
	_g_free0 (_tmp4_);
	g_object_ref_sink (_tmp5_);
	format_button = _tmp5_;
	_tmp6_ = self->priv->_doc;
	_tmp7_ = scratch_services_document_get_language_id (_tmp6_);
	sel_lang = _tmp7_;
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp8_ = FALSE;
			_tmp8_ = TRUE;
			while (TRUE) {
				gchar** _tmp10_;
				gint _tmp10__length1;
				gint _tmp10__length2;
				gint _tmp11_;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_;
				gint _tmp13__length1;
				gint _tmp13__length2;
				const gchar* _tmp14_;
				gchar** _tmp22_;
				gint _tmp22__length1;
				gint _tmp22__length2;
				const gchar* _tmp23_;
				const gchar* _tmp24_;
				if (!_tmp8_) {
					gint _tmp9_;
					_tmp9_ = i;
					i = _tmp9_ + 1;
				}
				_tmp8_ = FALSE;
				_tmp10_ = self->languages;
				_tmp10__length1 = self->languages_length1;
				_tmp10__length2 = self->languages_length2;
				_tmp11_ = _tmp10__length1;
				if (!(i < _tmp11_)) {
					break;
				}
				_tmp13_ = self->languages;
				_tmp13__length1 = self->languages_length1;
				_tmp13__length2 = self->languages_length2;
				_tmp14_ = _tmp13_[(i * _tmp13__length2) + 3];
				if (g_strcmp0 (_tmp14_, "") != 0) {
					_tmp12_ = TRUE;
				} else {
					gchar** _tmp15_;
					gint _tmp15__length1;
					gint _tmp15__length2;
					const gchar* _tmp16_;
					_tmp15_ = self->languages;
					_tmp15__length1 = self->languages_length1;
					_tmp15__length2 = self->languages_length2;
					_tmp16_ = _tmp15_[(i * _tmp15__length2) + 0];
					_tmp12_ = g_strcmp0 (_tmp16_, "y") == 0;
				}
				if (_tmp12_) {
					GtkComboBoxText* _tmp17_;
					gchar** _tmp18_;
					gint _tmp18__length1;
					gint _tmp18__length2;
					const gchar* _tmp19_;
					gchar** _tmp20_;
					gint _tmp20__length1;
					gint _tmp20__length2;
					const gchar* _tmp21_;
					_tmp17_ = self->priv->format_combo;
					_tmp18_ = self->languages;
					_tmp18__length1 = self->languages_length1;
					_tmp18__length2 = self->languages_length2;
					_tmp19_ = _tmp18_[(i * _tmp18__length2) + 1];
					_tmp20_ = self->languages;
					_tmp20__length1 = self->languages_length1;
					_tmp20__length2 = self->languages_length2;
					_tmp21_ = _tmp20_[(i * _tmp20__length2) + 2];
					gtk_combo_box_text_append (_tmp17_, _tmp19_, _tmp21_);
				}
				_tmp22_ = self->languages;
				_tmp22__length1 = self->languages_length1;
				_tmp22__length2 = self->languages_length2;
				_tmp23_ = _tmp22_[(i * _tmp22__length2) + 3];
				_tmp24_ = sel_lang;
				if (g_strcmp0 (_tmp23_, _tmp24_) == 0) {
					GtkComboBoxText* _tmp25_;
					gchar** _tmp26_;
					gint _tmp26__length1;
					gint _tmp26__length2;
					const gchar* _tmp27_;
					_tmp25_ = self->priv->format_combo;
					_tmp26_ = self->languages;
					_tmp26__length1 = self->languages_length1;
					_tmp26__length2 = self->languages_length2;
					_tmp27_ = _tmp26_[(i * _tmp26__length2) + 1];
					gtk_combo_box_set_active_id ((GtkComboBox*) _tmp25_, _tmp27_);
				}
			}
		}
	}
	_tmp28_ = self->priv->format_combo;
	_tmp29_ = gtk_combo_box_get_active_id ((GtkComboBox*) _tmp28_);
	if (_tmp29_ == NULL) {
		GtkComboBoxText* _tmp30_;
		_tmp30_ = self->priv->format_combo;
		gtk_combo_box_set_active_id ((GtkComboBox*) _tmp30_, "text");
	}
	_tmp31_ = (GtkLabel*) gtk_label_new (_ ("Expiration:"));
	gtk_widget_set_halign ((GtkWidget*) _tmp31_, GTK_ALIGN_END);
	g_object_ref_sink (_tmp31_);
	expiry_combo_l = _tmp31_;
	_tmp32_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
	g_object_ref_sink (_tmp32_);
	_g_object_unref0 (self->priv->expiry_combo);
	self->priv->expiry_combo = _tmp32_;
	scratch_dialogs_paste_bin_dialog_populate_expiry_combo (self);
	_tmp33_ = (GtkCheckButton*) gtk_check_button_new_with_label (_ ("Keep this paste private"));
	g_object_ref_sink (_tmp33_);
	_g_object_unref0 (self->priv->private_check);
	self->priv->private_check = _tmp33_;
	_tmp34_ = (GtkGrid*) gtk_grid_new ();
	gtk_grid_set_column_spacing (_tmp34_, 6);
	gtk_grid_set_row_spacing (_tmp34_, 12);
	g_object_ref_sink (_tmp34_);
	grid = _tmp34_;
	_tmp35_ = grid;
	_tmp36_ = name_entry_l;
	gtk_grid_attach (_tmp35_, (GtkWidget*) _tmp36_, 0, 0, 1, 1);
	_tmp37_ = grid;
	_tmp38_ = self->priv->name_entry;
	gtk_grid_attach (_tmp37_, (GtkWidget*) _tmp38_, 1, 0, 1, 1);
	_tmp39_ = grid;
	_tmp40_ = format_label;
	gtk_grid_attach (_tmp39_, (GtkWidget*) _tmp40_, 0, 1, 1, 1);
	_tmp41_ = grid;
	_tmp42_ = self->priv->format_combo;
	gtk_grid_attach (_tmp41_, (GtkWidget*) _tmp42_, 1, 1, 1, 1);
	_tmp43_ = grid;
	_tmp44_ = format_button;
	gtk_grid_attach (_tmp43_, (GtkWidget*) _tmp44_, 2, 1, 1, 1);
	_tmp45_ = grid;
	_tmp46_ = expiry_combo_l;
	gtk_grid_attach (_tmp45_, (GtkWidget*) _tmp46_, 0, 2, 1, 1);
	_tmp47_ = grid;
	_tmp48_ = self->priv->expiry_combo;
	gtk_grid_attach (_tmp47_, (GtkWidget*) _tmp48_, 1, 2, 1, 1);
	_tmp49_ = grid;
	_tmp50_ = self->priv->private_check;
	gtk_grid_attach (_tmp49_, (GtkWidget*) _tmp50_, 1, 3, 1, 1);
	_tmp51_ = (GtkSpinner*) gtk_spinner_new ();
	g_object_set (_tmp51_, "active", TRUE, NULL);
	g_object_set ((GtkWidget*) _tmp51_, "height-request", 32, NULL);
	gtk_widget_set_valign ((GtkWidget*) _tmp51_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp51_);
	_data1_->spinner = _tmp51_;
	_tmp52_ = (GtkStack*) gtk_stack_new ();
	g_object_set ((GtkWidget*) _tmp52_, "margin", 12, NULL);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp52_, 0);
	g_object_ref_sink (_tmp52_);
	_g_object_unref0 (self->priv->stack);
	self->priv->stack = _tmp52_;
	_tmp53_ = self->priv->stack;
	_tmp54_ = grid;
	gtk_container_add ((GtkContainer*) _tmp53_, (GtkWidget*) _tmp54_);
	_tmp55_ = self->priv->stack;
	_tmp56_ = _data1_->spinner;
	gtk_container_add ((GtkContainer*) _tmp55_, (GtkWidget*) _tmp56_);
	_tmp57_ = gtk_dialog_get_content_area ((GtkDialog*) self);
	_tmp58_ = self->priv->stack;
	gtk_container_add ((GtkContainer*) _tmp57_, (GtkWidget*) _tmp58_);
	_tmp59_ = gtk_dialog_add_button ((GtkDialog*) self, _ ("Cancel"), (gint) GTK_RESPONSE_CANCEL);
	_tmp60_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, gtk_button_get_type (), GtkButton));
	_g_object_unref0 (self->priv->close_button);
	self->priv->close_button = _tmp60_;
	_tmp61_ = gtk_dialog_add_button ((GtkDialog*) self, _ ("Upload to Pastebin"), (gint) GTK_RESPONSE_OK);
	_tmp62_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, gtk_button_get_type (), GtkButton));
	_g_object_unref0 (self->priv->upload_button);
	self->priv->upload_button = _tmp62_;
	_tmp63_ = self->priv->upload_button;
	_tmp64_ = gtk_widget_get_style_context ((GtkWidget*) _tmp63_);
	gtk_style_context_add_class (_tmp64_, GTK_STYLE_CLASS_SUGGESTED_ACTION);
	scratch_dialogs_paste_bin_dialog_read_settings (self);
	gtk_widget_show_all ((GtkWidget*) self);
	_tmp65_ = format_button;
	g_signal_connect_object (_tmp65_, "clicked", (GCallback) _scratch_dialogs_paste_bin_dialog_format_button_clicked_gtk_button_clicked, self, 0);
	_tmp66_ = self->priv->upload_button;
	g_signal_connect_data (_tmp66_, "clicked", (GCallback) __scratch_dialogs_paste_bin_dialog___lambda5__gtk_button_clicked, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
	_tmp67_ = self->priv->close_button;
	g_signal_connect_object (_tmp67_, "clicked", (GCallback) __scratch_dialogs_paste_bin_dialog___lambda6__gtk_button_clicked, self, 0);
	g_signal_connect_object ((GtkWidget*) self, "destroy", (GCallback) __scratch_dialogs_paste_bin_dialog___lambda7__gtk_widget_destroy, self, 0);
	_g_object_unref0 (grid);
	_g_object_unref0 (expiry_combo_l);
	_g_free0 (sel_lang);
	_g_object_unref0 (format_button);
	_g_object_unref0 (format_label);
	_g_object_unref0 (name_entry_l);
	block1_data_unref (_data1_);
	_data1_ = NULL;
	return obj;
}

static void
scratch_dialogs_paste_bin_dialog_class_init (ScratchDialogsPasteBinDialogClass * klass,
                                             gpointer klass_data)
{
	scratch_dialogs_paste_bin_dialog_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &ScratchDialogsPasteBinDialog_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_scratch_dialogs_paste_bin_dialog_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_scratch_dialogs_paste_bin_dialog_set_property;
	G_OBJECT_CLASS (klass)->constructor = scratch_dialogs_paste_bin_dialog_constructor;
	G_OBJECT_CLASS (klass)->finalize = scratch_dialogs_paste_bin_dialog_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), SCRATCH_DIALOGS_PASTE_BIN_DIALOG_DOC_PROPERTY, scratch_dialogs_paste_bin_dialog_properties[SCRATCH_DIALOGS_PASTE_BIN_DIALOG_DOC_PROPERTY] = g_param_spec_object ("doc", "doc", "doc", SCRATCH_SERVICES_TYPE_DOCUMENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
}

static void
scratch_dialogs_paste_bin_dialog_instance_init (ScratchDialogsPasteBinDialog * self,
                                                gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	gchar* _tmp41_;
	gchar* _tmp42_;
	gchar* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	gchar* _tmp47_;
	gchar* _tmp48_;
	gchar* _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	gchar* _tmp52_;
	gchar* _tmp53_;
	gchar* _tmp54_;
	gchar* _tmp55_;
	gchar* _tmp56_;
	gchar* _tmp57_;
	gchar* _tmp58_;
	gchar* _tmp59_;
	gchar* _tmp60_;
	gchar* _tmp61_;
	gchar* _tmp62_;
	gchar* _tmp63_;
	gchar* _tmp64_;
	gchar* _tmp65_;
	gchar* _tmp66_;
	gchar* _tmp67_;
	gchar* _tmp68_;
	gchar* _tmp69_;
	gchar* _tmp70_;
	gchar* _tmp71_;
	gchar* _tmp72_;
	gchar* _tmp73_;
	gchar* _tmp74_;
	gchar* _tmp75_;
	gchar* _tmp76_;
	gchar* _tmp77_;
	gchar* _tmp78_;
	gchar* _tmp79_;
	gchar* _tmp80_;
	gchar* _tmp81_;
	gchar* _tmp82_;
	gchar* _tmp83_;
	gchar* _tmp84_;
	gchar* _tmp85_;
	gchar* _tmp86_;
	gchar* _tmp87_;
	gchar* _tmp88_;
	gchar* _tmp89_;
	gchar* _tmp90_;
	gchar* _tmp91_;
	gchar* _tmp92_;
	gchar* _tmp93_;
	gchar* _tmp94_;
	gchar* _tmp95_;
	gchar* _tmp96_;
	gchar* _tmp97_;
	gchar* _tmp98_;
	gchar* _tmp99_;
	gchar* _tmp100_;
	gchar* _tmp101_;
	gchar* _tmp102_;
	gchar* _tmp103_;
	gchar* _tmp104_;
	gchar* _tmp105_;
	gchar* _tmp106_;
	gchar* _tmp107_;
	gchar* _tmp108_;
	gchar* _tmp109_;
	gchar* _tmp110_;
	gchar* _tmp111_;
	gchar* _tmp112_;
	gchar* _tmp113_;
	gchar* _tmp114_;
	gchar* _tmp115_;
	gchar* _tmp116_;
	gchar* _tmp117_;
	gchar* _tmp118_;
	gchar* _tmp119_;
	gchar* _tmp120_;
	gchar* _tmp121_;
	gchar* _tmp122_;
	gchar* _tmp123_;
	gchar* _tmp124_;
	gchar* _tmp125_;
	gchar* _tmp126_;
	gchar* _tmp127_;
	gchar* _tmp128_;
	gchar* _tmp129_;
	gchar* _tmp130_;
	gchar* _tmp131_;
	gchar* _tmp132_;
	gchar* _tmp133_;
	gchar* _tmp134_;
	gchar* _tmp135_;
	gchar* _tmp136_;
	gchar* _tmp137_;
	gchar* _tmp138_;
	gchar* _tmp139_;
	gchar* _tmp140_;
	gchar* _tmp141_;
	gchar* _tmp142_;
	gchar* _tmp143_;
	gchar* _tmp144_;
	gchar* _tmp145_;
	gchar* _tmp146_;
	gchar* _tmp147_;
	gchar* _tmp148_;
	gchar* _tmp149_;
	gchar* _tmp150_;
	gchar* _tmp151_;
	gchar* _tmp152_;
	gchar* _tmp153_;
	gchar* _tmp154_;
	gchar* _tmp155_;
	gchar* _tmp156_;
	gchar* _tmp157_;
	gchar* _tmp158_;
	gchar* _tmp159_;
	gchar* _tmp160_;
	gchar* _tmp161_;
	gchar* _tmp162_;
	gchar* _tmp163_;
	gchar* _tmp164_;
	gchar* _tmp165_;
	gchar* _tmp166_;
	gchar* _tmp167_;
	gchar* _tmp168_;
	gchar* _tmp169_;
	gchar* _tmp170_;
	gchar* _tmp171_;
	gchar* _tmp172_;
	gchar* _tmp173_;
	gchar* _tmp174_;
	gchar* _tmp175_;
	gchar* _tmp176_;
	gchar* _tmp177_;
	gchar* _tmp178_;
	gchar* _tmp179_;
	gchar* _tmp180_;
	gchar* _tmp181_;
	gchar* _tmp182_;
	gchar* _tmp183_;
	gchar* _tmp184_;
	gchar* _tmp185_;
	gchar* _tmp186_;
	gchar* _tmp187_;
	gchar* _tmp188_;
	gchar* _tmp189_;
	gchar* _tmp190_;
	gchar* _tmp191_;
	gchar* _tmp192_;
	gchar* _tmp193_;
	gchar* _tmp194_;
	gchar* _tmp195_;
	gchar* _tmp196_;
	gchar* _tmp197_;
	gchar* _tmp198_;
	gchar* _tmp199_;
	gchar* _tmp200_;
	gchar* _tmp201_;
	gchar* _tmp202_;
	gchar* _tmp203_;
	gchar* _tmp204_;
	gchar* _tmp205_;
	gchar* _tmp206_;
	gchar* _tmp207_;
	gchar* _tmp208_;
	gchar* _tmp209_;
	gchar* _tmp210_;
	gchar* _tmp211_;
	gchar* _tmp212_;
	gchar* _tmp213_;
	gchar* _tmp214_;
	gchar* _tmp215_;
	gchar* _tmp216_;
	gchar* _tmp217_;
	gchar* _tmp218_;
	gchar* _tmp219_;
	gchar* _tmp220_;
	gchar* _tmp221_;
	gchar* _tmp222_;
	gchar* _tmp223_;
	gchar* _tmp224_;
	gchar* _tmp225_;
	gchar* _tmp226_;
	gchar* _tmp227_;
	gchar* _tmp228_;
	gchar* _tmp229_;
	gchar* _tmp230_;
	gchar* _tmp231_;
	gchar* _tmp232_;
	gchar* _tmp233_;
	gchar* _tmp234_;
	gchar* _tmp235_;
	gchar* _tmp236_;
	gchar* _tmp237_;
	gchar* _tmp238_;
	gchar* _tmp239_;
	gchar* _tmp240_;
	gchar* _tmp241_;
	gchar* _tmp242_;
	gchar* _tmp243_;
	gchar* _tmp244_;
	gchar* _tmp245_;
	gchar* _tmp246_;
	gchar* _tmp247_;
	gchar* _tmp248_;
	gchar* _tmp249_;
	gchar* _tmp250_;
	gchar* _tmp251_;
	gchar* _tmp252_;
	gchar* _tmp253_;
	gchar* _tmp254_;
	gchar* _tmp255_;
	gchar* _tmp256_;
	gchar* _tmp257_;
	gchar* _tmp258_;
	gchar* _tmp259_;
	gchar* _tmp260_;
	gchar* _tmp261_;
	gchar* _tmp262_;
	gchar* _tmp263_;
	gchar* _tmp264_;
	gchar* _tmp265_;
	gchar* _tmp266_;
	gchar* _tmp267_;
	gchar* _tmp268_;
	gchar* _tmp269_;
	gchar* _tmp270_;
	gchar* _tmp271_;
	gchar* _tmp272_;
	gchar* _tmp273_;
	gchar* _tmp274_;
	gchar* _tmp275_;
	gchar* _tmp276_;
	gchar* _tmp277_;
	gchar* _tmp278_;
	gchar* _tmp279_;
	gchar* _tmp280_;
	gchar* _tmp281_;
	gchar* _tmp282_;
	gchar* _tmp283_;
	gchar* _tmp284_;
	gchar* _tmp285_;
	gchar* _tmp286_;
	gchar* _tmp287_;
	gchar* _tmp288_;
	gchar* _tmp289_;
	gchar* _tmp290_;
	gchar* _tmp291_;
	gchar* _tmp292_;
	gchar* _tmp293_;
	gchar* _tmp294_;
	gchar* _tmp295_;
	gchar* _tmp296_;
	gchar* _tmp297_;
	gchar* _tmp298_;
	gchar* _tmp299_;
	gchar* _tmp300_;
	gchar* _tmp301_;
	gchar* _tmp302_;
	gchar* _tmp303_;
	gchar* _tmp304_;
	gchar* _tmp305_;
	gchar* _tmp306_;
	gchar* _tmp307_;
	gchar* _tmp308_;
	gchar* _tmp309_;
	gchar* _tmp310_;
	gchar* _tmp311_;
	gchar* _tmp312_;
	gchar* _tmp313_;
	gchar* _tmp314_;
	gchar* _tmp315_;
	gchar* _tmp316_;
	gchar* _tmp317_;
	gchar* _tmp318_;
	gchar* _tmp319_;
	gchar* _tmp320_;
	gchar* _tmp321_;
	gchar* _tmp322_;
	gchar* _tmp323_;
	gchar* _tmp324_;
	gchar* _tmp325_;
	gchar* _tmp326_;
	gchar* _tmp327_;
	gchar* _tmp328_;
	gchar* _tmp329_;
	gchar* _tmp330_;
	gchar* _tmp331_;
	gchar* _tmp332_;
	gchar* _tmp333_;
	gchar* _tmp334_;
	gchar* _tmp335_;
	gchar* _tmp336_;
	gchar* _tmp337_;
	gchar* _tmp338_;
	gchar* _tmp339_;
	gchar* _tmp340_;
	gchar* _tmp341_;
	gchar* _tmp342_;
	gchar* _tmp343_;
	gchar* _tmp344_;
	gchar* _tmp345_;
	gchar* _tmp346_;
	gchar* _tmp347_;
	gchar* _tmp348_;
	gchar* _tmp349_;
	gchar* _tmp350_;
	gchar* _tmp351_;
	gchar* _tmp352_;
	gchar* _tmp353_;
	gchar* _tmp354_;
	gchar* _tmp355_;
	gchar* _tmp356_;
	gchar* _tmp357_;
	gchar* _tmp358_;
	gchar* _tmp359_;
	gchar* _tmp360_;
	gchar* _tmp361_;
	gchar* _tmp362_;
	gchar* _tmp363_;
	gchar* _tmp364_;
	gchar* _tmp365_;
	gchar* _tmp366_;
	gchar* _tmp367_;
	gchar* _tmp368_;
	gchar* _tmp369_;
	gchar* _tmp370_;
	gchar* _tmp371_;
	gchar* _tmp372_;
	gchar* _tmp373_;
	gchar* _tmp374_;
	gchar* _tmp375_;
	gchar* _tmp376_;
	gchar* _tmp377_;
	gchar* _tmp378_;
	gchar* _tmp379_;
	gchar* _tmp380_;
	gchar* _tmp381_;
	gchar* _tmp382_;
	gchar* _tmp383_;
	gchar* _tmp384_;
	gchar* _tmp385_;
	gchar* _tmp386_;
	gchar* _tmp387_;
	gchar* _tmp388_;
	gchar* _tmp389_;
	gchar* _tmp390_;
	gchar* _tmp391_;
	gchar* _tmp392_;
	gchar* _tmp393_;
	gchar* _tmp394_;
	gchar* _tmp395_;
	gchar* _tmp396_;
	gchar* _tmp397_;
	gchar* _tmp398_;
	gchar* _tmp399_;
	gchar* _tmp400_;
	gchar* _tmp401_;
	gchar* _tmp402_;
	gchar* _tmp403_;
	gchar* _tmp404_;
	gchar* _tmp405_;
	gchar* _tmp406_;
	gchar* _tmp407_;
	gchar* _tmp408_;
	gchar* _tmp409_;
	gchar* _tmp410_;
	gchar* _tmp411_;
	gchar* _tmp412_;
	gchar* _tmp413_;
	gchar* _tmp414_;
	gchar* _tmp415_;
	gchar* _tmp416_;
	gchar* _tmp417_;
	gchar* _tmp418_;
	gchar* _tmp419_;
	gchar* _tmp420_;
	gchar* _tmp421_;
	gchar* _tmp422_;
	gchar* _tmp423_;
	gchar* _tmp424_;
	gchar* _tmp425_;
	gchar* _tmp426_;
	gchar* _tmp427_;
	gchar* _tmp428_;
	gchar* _tmp429_;
	gchar* _tmp430_;
	gchar* _tmp431_;
	gchar* _tmp432_;
	gchar* _tmp433_;
	gchar* _tmp434_;
	gchar* _tmp435_;
	gchar* _tmp436_;
	gchar* _tmp437_;
	gchar* _tmp438_;
	gchar* _tmp439_;
	gchar* _tmp440_;
	gchar* _tmp441_;
	gchar* _tmp442_;
	gchar* _tmp443_;
	gchar* _tmp444_;
	gchar* _tmp445_;
	gchar* _tmp446_;
	gchar* _tmp447_;
	gchar* _tmp448_;
	gchar* _tmp449_;
	gchar* _tmp450_;
	gchar* _tmp451_;
	gchar* _tmp452_;
	gchar* _tmp453_;
	gchar* _tmp454_;
	gchar* _tmp455_;
	gchar* _tmp456_;
	gchar* _tmp457_;
	gchar* _tmp458_;
	gchar* _tmp459_;
	gchar* _tmp460_;
	gchar* _tmp461_;
	gchar* _tmp462_;
	gchar* _tmp463_;
	gchar* _tmp464_;
	gchar* _tmp465_;
	gchar* _tmp466_;
	gchar* _tmp467_;
	gchar* _tmp468_;
	gchar* _tmp469_;
	gchar* _tmp470_;
	gchar* _tmp471_;
	gchar* _tmp472_;
	gchar* _tmp473_;
	gchar* _tmp474_;
	gchar* _tmp475_;
	gchar* _tmp476_;
	gchar* _tmp477_;
	gchar* _tmp478_;
	gchar* _tmp479_;
	gchar* _tmp480_;
	gchar* _tmp481_;
	gchar* _tmp482_;
	gchar* _tmp483_;
	gchar* _tmp484_;
	gchar* _tmp485_;
	gchar* _tmp486_;
	gchar* _tmp487_;
	gchar* _tmp488_;
	gchar* _tmp489_;
	gchar* _tmp490_;
	gchar* _tmp491_;
	gchar* _tmp492_;
	gchar* _tmp493_;
	gchar* _tmp494_;
	gchar* _tmp495_;
	gchar* _tmp496_;
	gchar* _tmp497_;
	gchar* _tmp498_;
	gchar* _tmp499_;
	gchar* _tmp500_;
	gchar* _tmp501_;
	gchar* _tmp502_;
	gchar* _tmp503_;
	gchar* _tmp504_;
	gchar* _tmp505_;
	gchar* _tmp506_;
	gchar* _tmp507_;
	gchar* _tmp508_;
	gchar* _tmp509_;
	gchar* _tmp510_;
	gchar* _tmp511_;
	gchar* _tmp512_;
	gchar* _tmp513_;
	gchar* _tmp514_;
	gchar* _tmp515_;
	gchar* _tmp516_;
	gchar* _tmp517_;
	gchar* _tmp518_;
	gchar* _tmp519_;
	gchar* _tmp520_;
	gchar* _tmp521_;
	gchar* _tmp522_;
	gchar* _tmp523_;
	gchar* _tmp524_;
	gchar* _tmp525_;
	gchar* _tmp526_;
	gchar* _tmp527_;
	gchar* _tmp528_;
	gchar* _tmp529_;
	gchar* _tmp530_;
	gchar* _tmp531_;
	gchar* _tmp532_;
	gchar* _tmp533_;
	gchar* _tmp534_;
	gchar* _tmp535_;
	gchar* _tmp536_;
	gchar* _tmp537_;
	gchar* _tmp538_;
	gchar* _tmp539_;
	gchar* _tmp540_;
	gchar* _tmp541_;
	gchar* _tmp542_;
	gchar* _tmp543_;
	gchar* _tmp544_;
	gchar* _tmp545_;
	gchar* _tmp546_;
	gchar* _tmp547_;
	gchar* _tmp548_;
	gchar* _tmp549_;
	gchar* _tmp550_;
	gchar* _tmp551_;
	gchar* _tmp552_;
	gchar* _tmp553_;
	gchar* _tmp554_;
	gchar* _tmp555_;
	gchar* _tmp556_;
	gchar* _tmp557_;
	gchar* _tmp558_;
	gchar* _tmp559_;
	gchar* _tmp560_;
	gchar* _tmp561_;
	gchar* _tmp562_;
	gchar* _tmp563_;
	gchar* _tmp564_;
	gchar* _tmp565_;
	gchar* _tmp566_;
	gchar* _tmp567_;
	gchar* _tmp568_;
	gchar* _tmp569_;
	gchar* _tmp570_;
	gchar* _tmp571_;
	gchar* _tmp572_;
	gchar* _tmp573_;
	gchar* _tmp574_;
	gchar* _tmp575_;
	gchar* _tmp576_;
	gchar* _tmp577_;
	gchar* _tmp578_;
	gchar* _tmp579_;
	gchar* _tmp580_;
	gchar* _tmp581_;
	gchar* _tmp582_;
	gchar* _tmp583_;
	gchar* _tmp584_;
	gchar* _tmp585_;
	gchar* _tmp586_;
	gchar* _tmp587_;
	gchar* _tmp588_;
	gchar* _tmp589_;
	gchar* _tmp590_;
	gchar* _tmp591_;
	gchar* _tmp592_;
	gchar* _tmp593_;
	gchar* _tmp594_;
	gchar* _tmp595_;
	gchar* _tmp596_;
	gchar* _tmp597_;
	gchar* _tmp598_;
	gchar* _tmp599_;
	gchar* _tmp600_;
	gchar* _tmp601_;
	gchar* _tmp602_;
	gchar* _tmp603_;
	gchar* _tmp604_;
	gchar* _tmp605_;
	gchar* _tmp606_;
	gchar* _tmp607_;
	gchar* _tmp608_;
	gchar* _tmp609_;
	gchar* _tmp610_;
	gchar* _tmp611_;
	gchar* _tmp612_;
	gchar* _tmp613_;
	gchar* _tmp614_;
	gchar* _tmp615_;
	gchar* _tmp616_;
	gchar* _tmp617_;
	gchar* _tmp618_;
	gchar* _tmp619_;
	gchar* _tmp620_;
	gchar* _tmp621_;
	gchar* _tmp622_;
	gchar* _tmp623_;
	gchar* _tmp624_;
	gchar* _tmp625_;
	gchar* _tmp626_;
	gchar* _tmp627_;
	gchar* _tmp628_;
	gchar* _tmp629_;
	gchar* _tmp630_;
	gchar* _tmp631_;
	gchar* _tmp632_;
	gchar* _tmp633_;
	gchar* _tmp634_;
	gchar* _tmp635_;
	gchar* _tmp636_;
	gchar* _tmp637_;
	gchar* _tmp638_;
	gchar* _tmp639_;
	gchar* _tmp640_;
	gchar* _tmp641_;
	gchar* _tmp642_;
	gchar* _tmp643_;
	gchar* _tmp644_;
	gchar* _tmp645_;
	gchar* _tmp646_;
	gchar* _tmp647_;
	gchar* _tmp648_;
	gchar* _tmp649_;
	gchar* _tmp650_;
	gchar* _tmp651_;
	gchar* _tmp652_;
	gchar* _tmp653_;
	gchar* _tmp654_;
	gchar* _tmp655_;
	gchar* _tmp656_;
	gchar* _tmp657_;
	gchar* _tmp658_;
	gchar* _tmp659_;
	gchar* _tmp660_;
	gchar* _tmp661_;
	gchar* _tmp662_;
	gchar* _tmp663_;
	gchar* _tmp664_;
	gchar* _tmp665_;
	gchar* _tmp666_;
	gchar* _tmp667_;
	gchar* _tmp668_;
	gchar* _tmp669_;
	gchar* _tmp670_;
	gchar* _tmp671_;
	gchar* _tmp672_;
	gchar* _tmp673_;
	gchar* _tmp674_;
	gchar* _tmp675_;
	gchar* _tmp676_;
	gchar* _tmp677_;
	gchar* _tmp678_;
	gchar* _tmp679_;
	gchar* _tmp680_;
	gchar* _tmp681_;
	gchar* _tmp682_;
	gchar* _tmp683_;
	gchar* _tmp684_;
	gchar* _tmp685_;
	gchar* _tmp686_;
	gchar* _tmp687_;
	gchar* _tmp688_;
	gchar* _tmp689_;
	gchar* _tmp690_;
	gchar* _tmp691_;
	gchar* _tmp692_;
	gchar* _tmp693_;
	gchar* _tmp694_;
	gchar* _tmp695_;
	gchar* _tmp696_;
	gchar* _tmp697_;
	gchar* _tmp698_;
	gchar* _tmp699_;
	gchar* _tmp700_;
	gchar* _tmp701_;
	gchar* _tmp702_;
	gchar* _tmp703_;
	gchar* _tmp704_;
	gchar* _tmp705_;
	gchar* _tmp706_;
	gchar* _tmp707_;
	gchar* _tmp708_;
	gchar* _tmp709_;
	gchar* _tmp710_;
	gchar* _tmp711_;
	gchar* _tmp712_;
	gchar* _tmp713_;
	gchar* _tmp714_;
	gchar* _tmp715_;
	gchar* _tmp716_;
	gchar* _tmp717_;
	gchar* _tmp718_;
	gchar* _tmp719_;
	gchar* _tmp720_;
	gchar* _tmp721_;
	gchar* _tmp722_;
	gchar* _tmp723_;
	gchar* _tmp724_;
	gchar* _tmp725_;
	gchar* _tmp726_;
	gchar* _tmp727_;
	gchar* _tmp728_;
	gchar* _tmp729_;
	gchar* _tmp730_;
	gchar* _tmp731_;
	gchar* _tmp732_;
	gchar* _tmp733_;
	gchar* _tmp734_;
	gchar* _tmp735_;
	gchar* _tmp736_;
	gchar* _tmp737_;
	gchar* _tmp738_;
	gchar* _tmp739_;
	gchar* _tmp740_;
	gchar* _tmp741_;
	gchar* _tmp742_;
	gchar* _tmp743_;
	gchar* _tmp744_;
	gchar* _tmp745_;
	gchar* _tmp746_;
	gchar* _tmp747_;
	gchar* _tmp748_;
	gchar* _tmp749_;
	gchar* _tmp750_;
	gchar* _tmp751_;
	gchar* _tmp752_;
	gchar* _tmp753_;
	gchar* _tmp754_;
	gchar* _tmp755_;
	gchar* _tmp756_;
	gchar* _tmp757_;
	gchar* _tmp758_;
	gchar* _tmp759_;
	gchar* _tmp760_;
	gchar* _tmp761_;
	gchar* _tmp762_;
	gchar* _tmp763_;
	gchar* _tmp764_;
	gchar* _tmp765_;
	gchar* _tmp766_;
	gchar* _tmp767_;
	gchar* _tmp768_;
	gchar* _tmp769_;
	gchar* _tmp770_;
	gchar* _tmp771_;
	gchar* _tmp772_;
	gchar* _tmp773_;
	gchar* _tmp774_;
	gchar* _tmp775_;
	gchar* _tmp776_;
	gchar* _tmp777_;
	gchar* _tmp778_;
	gchar* _tmp779_;
	gchar* _tmp780_;
	gchar* _tmp781_;
	gchar* _tmp782_;
	gchar* _tmp783_;
	gchar* _tmp784_;
	gchar* _tmp785_;
	gchar* _tmp786_;
	gchar* _tmp787_;
	gchar* _tmp788_;
	gchar* _tmp789_;
	gchar* _tmp790_;
	gchar* _tmp791_;
	gchar* _tmp792_;
	gchar* _tmp793_;
	gchar* _tmp794_;
	gchar* _tmp795_;
	gchar* _tmp796_;
	gchar* _tmp797_;
	gchar* _tmp798_;
	gchar* _tmp799_;
	gchar** _tmp800_;
	self->priv = scratch_dialogs_paste_bin_dialog_get_instance_private (self);
	_tmp0_ = g_strdup ("n");
	_tmp1_ = g_strdup ("text");
	_tmp2_ = g_strdup ("None");
	_tmp3_ = g_strdup ("text");
	_tmp4_ = g_strdup ("n");
	_tmp5_ = g_strdup ("4cs");
	_tmp6_ = g_strdup ("4CS");
	_tmp7_ = g_strdup ("");
	_tmp8_ = g_strdup ("n");
	_tmp9_ = g_strdup ("6502acme");
	_tmp10_ = g_strdup ("6502 ACME Cross Assembler");
	_tmp11_ = g_strdup ("");
	_tmp12_ = g_strdup ("n");
	_tmp13_ = g_strdup ("6502kickass");
	_tmp14_ = g_strdup ("6502 Kick Assembler");
	_tmp15_ = g_strdup ("");
	_tmp16_ = g_strdup ("n");
	_tmp17_ = g_strdup ("6502tasm");
	_tmp18_ = g_strdup ("6502 TASM/64TASS");
	_tmp19_ = g_strdup ("");
	_tmp20_ = g_strdup ("n");
	_tmp21_ = g_strdup ("abap");
	_tmp22_ = g_strdup ("ABAP");
	_tmp23_ = g_strdup ("");
	_tmp24_ = g_strdup ("n");
	_tmp25_ = g_strdup ("actionscript");
	_tmp26_ = g_strdup ("ActionScript");
	_tmp27_ = g_strdup ("");
	_tmp28_ = g_strdup ("n");
	_tmp29_ = g_strdup ("actionscript3");
	_tmp30_ = g_strdup ("ActionScript 3");
	_tmp31_ = g_strdup ("");
	_tmp32_ = g_strdup ("n");
	_tmp33_ = g_strdup ("ada");
	_tmp34_ = g_strdup ("Ada");
	_tmp35_ = g_strdup ("");
	_tmp36_ = g_strdup ("n");
	_tmp37_ = g_strdup ("algol68");
	_tmp38_ = g_strdup ("ALGOL 68");
	_tmp39_ = g_strdup ("");
	_tmp40_ = g_strdup ("n");
	_tmp41_ = g_strdup ("apache");
	_tmp42_ = g_strdup ("Apache Log");
	_tmp43_ = g_strdup ("");
	_tmp44_ = g_strdup ("n");
	_tmp45_ = g_strdup ("applescript");
	_tmp46_ = g_strdup ("AppleScript");
	_tmp47_ = g_strdup ("");
	_tmp48_ = g_strdup ("n");
	_tmp49_ = g_strdup ("apt_sources");
	_tmp50_ = g_strdup ("APT Sources");
	_tmp51_ = g_strdup ("");
	_tmp52_ = g_strdup ("n");
	_tmp53_ = g_strdup ("asm");
	_tmp54_ = g_strdup ("ASM (NASM)");
	_tmp55_ = g_strdup ("");
	_tmp56_ = g_strdup ("n");
	_tmp57_ = g_strdup ("asp");
	_tmp58_ = g_strdup ("ASP");
	_tmp59_ = g_strdup ("");
	_tmp60_ = g_strdup ("n");
	_tmp61_ = g_strdup ("autoconf");
	_tmp62_ = g_strdup ("autoconf");
	_tmp63_ = g_strdup ("");
	_tmp64_ = g_strdup ("n");
	_tmp65_ = g_strdup ("autohotkey");
	_tmp66_ = g_strdup ("Autohotkey");
	_tmp67_ = g_strdup ("");
	_tmp68_ = g_strdup ("n");
	_tmp69_ = g_strdup ("autoit");
	_tmp70_ = g_strdup ("AutoIt");
	_tmp71_ = g_strdup ("");
	_tmp72_ = g_strdup ("n");
	_tmp73_ = g_strdup ("avisynth");
	_tmp74_ = g_strdup ("Avisynth");
	_tmp75_ = g_strdup ("");
	_tmp76_ = g_strdup ("n");
	_tmp77_ = g_strdup ("awk");
	_tmp78_ = g_strdup ("Awk");
	_tmp79_ = g_strdup ("");
	_tmp80_ = g_strdup ("n");
	_tmp81_ = g_strdup ("bascomavr");
	_tmp82_ = g_strdup ("BASCOM AVR");
	_tmp83_ = g_strdup ("");
	_tmp84_ = g_strdup ("n");
	_tmp85_ = g_strdup ("bash");
	_tmp86_ = g_strdup ("Bash");
	_tmp87_ = g_strdup ("sh");
	_tmp88_ = g_strdup ("n");
	_tmp89_ = g_strdup ("basic4gl");
	_tmp90_ = g_strdup ("Basic4GL");
	_tmp91_ = g_strdup ("");
	_tmp92_ = g_strdup ("n");
	_tmp93_ = g_strdup ("bibtex");
	_tmp94_ = g_strdup ("BibTeX");
	_tmp95_ = g_strdup ("");
	_tmp96_ = g_strdup ("n");
	_tmp97_ = g_strdup ("blitzbasic");
	_tmp98_ = g_strdup ("Blitz Basic");
	_tmp99_ = g_strdup ("");
	_tmp100_ = g_strdup ("n");
	_tmp101_ = g_strdup ("bnf");
	_tmp102_ = g_strdup ("BNF");
	_tmp103_ = g_strdup ("");
	_tmp104_ = g_strdup ("n");
	_tmp105_ = g_strdup ("boo");
	_tmp106_ = g_strdup ("BOO");
	_tmp107_ = g_strdup ("");
	_tmp108_ = g_strdup ("n");
	_tmp109_ = g_strdup ("bf");
	_tmp110_ = g_strdup ("BrainFuck");
	_tmp111_ = g_strdup ("");
	_tmp112_ = g_strdup ("n");
	_tmp113_ = g_strdup ("c");
	_tmp114_ = g_strdup ("C");
	_tmp115_ = g_strdup ("c");
	_tmp116_ = g_strdup ("n");
	_tmp117_ = g_strdup ("c_mac");
	_tmp118_ = g_strdup ("C for Macs");
	_tmp119_ = g_strdup ("");
	_tmp120_ = g_strdup ("n");
	_tmp121_ = g_strdup ("cil");
	_tmp122_ = g_strdup ("C Intermediate Language");
	_tmp123_ = g_strdup ("");
	_tmp124_ = g_strdup ("n");
	_tmp125_ = g_strdup ("csharp");
	_tmp126_ = g_strdup ("C#");
	_tmp127_ = g_strdup ("c-sharp");
	_tmp128_ = g_strdup ("n");
	_tmp129_ = g_strdup ("cpp");
	_tmp130_ = g_strdup ("C++");
	_tmp131_ = g_strdup ("cpp");
	_tmp132_ = g_strdup ("n");
	_tmp133_ = g_strdup ("cpp-qt");
	_tmp134_ = g_strdup ("C++ (with QT extensions)");
	_tmp135_ = g_strdup ("");
	_tmp136_ = g_strdup ("n");
	_tmp137_ = g_strdup ("c_loadrunner");
	_tmp138_ = g_strdup ("C: Loadrunner");
	_tmp139_ = g_strdup ("");
	_tmp140_ = g_strdup ("n");
	_tmp141_ = g_strdup ("caddcl");
	_tmp142_ = g_strdup ("CAD DCL");
	_tmp143_ = g_strdup ("");
	_tmp144_ = g_strdup ("n");
	_tmp145_ = g_strdup ("cadlisp");
	_tmp146_ = g_strdup ("CAD Lisp");
	_tmp147_ = g_strdup ("");
	_tmp148_ = g_strdup ("n");
	_tmp149_ = g_strdup ("cfdg");
	_tmp150_ = g_strdup ("CFDG");
	_tmp151_ = g_strdup ("");
	_tmp152_ = g_strdup ("n");
	_tmp153_ = g_strdup ("chaiscript");
	_tmp154_ = g_strdup ("ChaiScript");
	_tmp155_ = g_strdup ("");
	_tmp156_ = g_strdup ("n");
	_tmp157_ = g_strdup ("clojure");
	_tmp158_ = g_strdup ("Clojure");
	_tmp159_ = g_strdup ("");
	_tmp160_ = g_strdup ("n");
	_tmp161_ = g_strdup ("klonec");
	_tmp162_ = g_strdup ("Clone C");
	_tmp163_ = g_strdup ("");
	_tmp164_ = g_strdup ("n");
	_tmp165_ = g_strdup ("klonecpp");
	_tmp166_ = g_strdup ("Clone C++");
	_tmp167_ = g_strdup ("");
	_tmp168_ = g_strdup ("n");
	_tmp169_ = g_strdup ("cmake");
	_tmp170_ = g_strdup ("CMake");
	_tmp171_ = g_strdup ("cmake");
	_tmp172_ = g_strdup ("n");
	_tmp173_ = g_strdup ("cobol");
	_tmp174_ = g_strdup ("COBOL");
	_tmp175_ = g_strdup ("");
	_tmp176_ = g_strdup ("n");
	_tmp177_ = g_strdup ("coffeescript");
	_tmp178_ = g_strdup ("CoffeeScript");
	_tmp179_ = g_strdup ("");
	_tmp180_ = g_strdup ("n");
	_tmp181_ = g_strdup ("cfm");
	_tmp182_ = g_strdup ("ColdFusion");
	_tmp183_ = g_strdup ("");
	_tmp184_ = g_strdup ("n");
	_tmp185_ = g_strdup ("css");
	_tmp186_ = g_strdup ("CSS");
	_tmp187_ = g_strdup ("css");
	_tmp188_ = g_strdup ("n");
	_tmp189_ = g_strdup ("cuesheet");
	_tmp190_ = g_strdup ("Cuesheet");
	_tmp191_ = g_strdup ("");
	_tmp192_ = g_strdup ("n");
	_tmp193_ = g_strdup ("d");
	_tmp194_ = g_strdup ("D");
	_tmp195_ = g_strdup ("");
	_tmp196_ = g_strdup ("n");
	_tmp197_ = g_strdup ("dcs");
	_tmp198_ = g_strdup ("DCS");
	_tmp199_ = g_strdup ("");
	_tmp200_ = g_strdup ("n");
	_tmp201_ = g_strdup ("delphi");
	_tmp202_ = g_strdup ("Delphi");
	_tmp203_ = g_strdup ("");
	_tmp204_ = g_strdup ("n");
	_tmp205_ = g_strdup ("oxygene");
	_tmp206_ = g_strdup ("Delphi Prism (Oxygene)");
	_tmp207_ = g_strdup ("");
	_tmp208_ = g_strdup ("n");
	_tmp209_ = g_strdup ("diff");
	_tmp210_ = g_strdup ("Diff");
	_tmp211_ = g_strdup ("diff");
	_tmp212_ = g_strdup ("n");
	_tmp213_ = g_strdup ("div");
	_tmp214_ = g_strdup ("DIV");
	_tmp215_ = g_strdup ("");
	_tmp216_ = g_strdup ("n");
	_tmp217_ = g_strdup ("dos");
	_tmp218_ = g_strdup ("DOS");
	_tmp219_ = g_strdup ("");
	_tmp220_ = g_strdup ("n");
	_tmp221_ = g_strdup ("dot");
	_tmp222_ = g_strdup ("DOT");
	_tmp223_ = g_strdup ("");
	_tmp224_ = g_strdup ("n");
	_tmp225_ = g_strdup ("e");
	_tmp226_ = g_strdup ("E");
	_tmp227_ = g_strdup ("");
	_tmp228_ = g_strdup ("n");
	_tmp229_ = g_strdup ("ecmascript");
	_tmp230_ = g_strdup ("ECMAScript");
	_tmp231_ = g_strdup ("");
	_tmp232_ = g_strdup ("n");
	_tmp233_ = g_strdup ("eiffel");
	_tmp234_ = g_strdup ("Eiffel");
	_tmp235_ = g_strdup ("");
	_tmp236_ = g_strdup ("n");
	_tmp237_ = g_strdup ("email");
	_tmp238_ = g_strdup ("Email");
	_tmp239_ = g_strdup ("");
	_tmp240_ = g_strdup ("n");
	_tmp241_ = g_strdup ("epc");
	_tmp242_ = g_strdup ("EPC");
	_tmp243_ = g_strdup ("");
	_tmp244_ = g_strdup ("n");
	_tmp245_ = g_strdup ("erlang");
	_tmp246_ = g_strdup ("Erlang");
	_tmp247_ = g_strdup ("");
	_tmp248_ = g_strdup ("n");
	_tmp249_ = g_strdup ("fsharp");
	_tmp250_ = g_strdup ("F#");
	_tmp251_ = g_strdup ("");
	_tmp252_ = g_strdup ("n");
	_tmp253_ = g_strdup ("falcon");
	_tmp254_ = g_strdup ("Falcon");
	_tmp255_ = g_strdup ("");
	_tmp256_ = g_strdup ("n");
	_tmp257_ = g_strdup ("fo");
	_tmp258_ = g_strdup ("FO Language");
	_tmp259_ = g_strdup ("");
	_tmp260_ = g_strdup ("n");
	_tmp261_ = g_strdup ("f1");
	_tmp262_ = g_strdup ("Formula One");
	_tmp263_ = g_strdup ("");
	_tmp264_ = g_strdup ("n");
	_tmp265_ = g_strdup ("fortran");
	_tmp266_ = g_strdup ("Fortran");
	_tmp267_ = g_strdup ("fortran");
	_tmp268_ = g_strdup ("n");
	_tmp269_ = g_strdup ("freebasic");
	_tmp270_ = g_strdup ("FreeBasic");
	_tmp271_ = g_strdup ("");
	_tmp272_ = g_strdup ("n");
	_tmp273_ = g_strdup ("gambas");
	_tmp274_ = g_strdup ("GAMBAS");
	_tmp275_ = g_strdup ("");
	_tmp276_ = g_strdup ("n");
	_tmp277_ = g_strdup ("gml");
	_tmp278_ = g_strdup ("Game Maker");
	_tmp279_ = g_strdup ("");
	_tmp280_ = g_strdup ("n");
	_tmp281_ = g_strdup ("gdb");
	_tmp282_ = g_strdup ("GDB");
	_tmp283_ = g_strdup ("");
	_tmp284_ = g_strdup ("n");
	_tmp285_ = g_strdup ("genero");
	_tmp286_ = g_strdup ("Genero");
	_tmp287_ = g_strdup ("");
	_tmp288_ = g_strdup ("n");
	_tmp289_ = g_strdup ("genie");
	_tmp290_ = g_strdup ("Genie");
	_tmp291_ = g_strdup ("");
	_tmp292_ = g_strdup ("n");
	_tmp293_ = g_strdup ("gettext");
	_tmp294_ = g_strdup ("GetText");
	_tmp295_ = g_strdup ("gettext-translation");
	_tmp296_ = g_strdup ("n");
	_tmp297_ = g_strdup ("go");
	_tmp298_ = g_strdup ("Go");
	_tmp299_ = g_strdup ("");
	_tmp300_ = g_strdup ("n");
	_tmp301_ = g_strdup ("groovy");
	_tmp302_ = g_strdup ("Groovy");
	_tmp303_ = g_strdup ("");
	_tmp304_ = g_strdup ("n");
	_tmp305_ = g_strdup ("gwbasic");
	_tmp306_ = g_strdup ("GwBasic");
	_tmp307_ = g_strdup ("");
	_tmp308_ = g_strdup ("n");
	_tmp309_ = g_strdup ("haskell");
	_tmp310_ = g_strdup ("Haskell");
	_tmp311_ = g_strdup ("");
	_tmp312_ = g_strdup ("n");
	_tmp313_ = g_strdup ("hicest");
	_tmp314_ = g_strdup ("HicEst");
	_tmp315_ = g_strdup ("");
	_tmp316_ = g_strdup ("n");
	_tmp317_ = g_strdup ("hq9plus");
	_tmp318_ = g_strdup ("HQ9 Plus");
	_tmp319_ = g_strdup ("");
	_tmp320_ = g_strdup ("n");
	_tmp321_ = g_strdup ("html4strict");
	_tmp322_ = g_strdup ("HTML");
	_tmp323_ = g_strdup ("html");
	_tmp324_ = g_strdup ("n");
	_tmp325_ = g_strdup ("html5");
	_tmp326_ = g_strdup ("HTML 5");
	_tmp327_ = g_strdup ("");
	_tmp328_ = g_strdup ("n");
	_tmp329_ = g_strdup ("icon");
	_tmp330_ = g_strdup ("Icon");
	_tmp331_ = g_strdup ("");
	_tmp332_ = g_strdup ("n");
	_tmp333_ = g_strdup ("idl");
	_tmp334_ = g_strdup ("IDL");
	_tmp335_ = g_strdup ("");
	_tmp336_ = g_strdup ("n");
	_tmp337_ = g_strdup ("ini");
	_tmp338_ = g_strdup ("INI file");
	_tmp339_ = g_strdup ("ini");
	_tmp340_ = g_strdup ("n");
	_tmp341_ = g_strdup ("inno");
	_tmp342_ = g_strdup ("Inno Script");
	_tmp343_ = g_strdup ("");
	_tmp344_ = g_strdup ("n");
	_tmp345_ = g_strdup ("intercal");
	_tmp346_ = g_strdup ("INTERCAL");
	_tmp347_ = g_strdup ("");
	_tmp348_ = g_strdup ("n");
	_tmp349_ = g_strdup ("io");
	_tmp350_ = g_strdup ("IO");
	_tmp351_ = g_strdup ("");
	_tmp352_ = g_strdup ("n");
	_tmp353_ = g_strdup ("j");
	_tmp354_ = g_strdup ("J");
	_tmp355_ = g_strdup ("");
	_tmp356_ = g_strdup ("n");
	_tmp357_ = g_strdup ("java");
	_tmp358_ = g_strdup ("Java");
	_tmp359_ = g_strdup ("java");
	_tmp360_ = g_strdup ("n");
	_tmp361_ = g_strdup ("java5");
	_tmp362_ = g_strdup ("Java 5");
	_tmp363_ = g_strdup ("");
	_tmp364_ = g_strdup ("n");
	_tmp365_ = g_strdup ("javascript");
	_tmp366_ = g_strdup ("JavaScript");
	_tmp367_ = g_strdup ("js");
	_tmp368_ = g_strdup ("n");
	_tmp369_ = g_strdup ("jquery");
	_tmp370_ = g_strdup ("jQuery");
	_tmp371_ = g_strdup ("");
	_tmp372_ = g_strdup ("n");
	_tmp373_ = g_strdup ("kixtart");
	_tmp374_ = g_strdup ("KiXtart");
	_tmp375_ = g_strdup ("");
	_tmp376_ = g_strdup ("n");
	_tmp377_ = g_strdup ("latex");
	_tmp378_ = g_strdup ("Latex");
	_tmp379_ = g_strdup ("latex");
	_tmp380_ = g_strdup ("n");
	_tmp381_ = g_strdup ("lb");
	_tmp382_ = g_strdup ("Liberty BASIC");
	_tmp383_ = g_strdup ("");
	_tmp384_ = g_strdup ("n");
	_tmp385_ = g_strdup ("lsl2");
	_tmp386_ = g_strdup ("Linden Scripting");
	_tmp387_ = g_strdup ("");
	_tmp388_ = g_strdup ("n");
	_tmp389_ = g_strdup ("lisp");
	_tmp390_ = g_strdup ("Lisp");
	_tmp391_ = g_strdup ("");
	_tmp392_ = g_strdup ("n");
	_tmp393_ = g_strdup ("llvm");
	_tmp394_ = g_strdup ("LLVM");
	_tmp395_ = g_strdup ("");
	_tmp396_ = g_strdup ("n");
	_tmp397_ = g_strdup ("locobasic");
	_tmp398_ = g_strdup ("Loco Basic");
	_tmp399_ = g_strdup ("");
	_tmp400_ = g_strdup ("n");
	_tmp401_ = g_strdup ("logtalk");
	_tmp402_ = g_strdup ("Logtalk");
	_tmp403_ = g_strdup ("");
	_tmp404_ = g_strdup ("n");
	_tmp405_ = g_strdup ("lolcode");
	_tmp406_ = g_strdup ("LOL Code");
	_tmp407_ = g_strdup ("");
	_tmp408_ = g_strdup ("n");
	_tmp409_ = g_strdup ("lotusformulas");
	_tmp410_ = g_strdup ("Lotus Formulas");
	_tmp411_ = g_strdup ("");
	_tmp412_ = g_strdup ("n");
	_tmp413_ = g_strdup ("lotusscript");
	_tmp414_ = g_strdup ("Lotus Script");
	_tmp415_ = g_strdup ("");
	_tmp416_ = g_strdup ("n");
	_tmp417_ = g_strdup ("lscript");
	_tmp418_ = g_strdup ("LScript");
	_tmp419_ = g_strdup ("");
	_tmp420_ = g_strdup ("n");
	_tmp421_ = g_strdup ("lua");
	_tmp422_ = g_strdup ("Lua");
	_tmp423_ = g_strdup ("lua");
	_tmp424_ = g_strdup ("n");
	_tmp425_ = g_strdup ("m68k");
	_tmp426_ = g_strdup ("M68000 Assembler");
	_tmp427_ = g_strdup ("");
	_tmp428_ = g_strdup ("n");
	_tmp429_ = g_strdup ("magiksf");
	_tmp430_ = g_strdup ("MagikSF");
	_tmp431_ = g_strdup ("");
	_tmp432_ = g_strdup ("n");
	_tmp433_ = g_strdup ("make");
	_tmp434_ = g_strdup ("Make");
	_tmp435_ = g_strdup ("makefile");
	_tmp436_ = g_strdup ("n");
	_tmp437_ = g_strdup ("mapbasic");
	_tmp438_ = g_strdup ("MapBasic");
	_tmp439_ = g_strdup ("");
	_tmp440_ = g_strdup ("n");
	_tmp441_ = g_strdup ("matlab");
	_tmp442_ = g_strdup ("MatLab");
	_tmp443_ = g_strdup ("");
	_tmp444_ = g_strdup ("n");
	_tmp445_ = g_strdup ("mirc");
	_tmp446_ = g_strdup ("mIRC");
	_tmp447_ = g_strdup ("");
	_tmp448_ = g_strdup ("n");
	_tmp449_ = g_strdup ("mmix");
	_tmp450_ = g_strdup ("MIX Assembler");
	_tmp451_ = g_strdup ("");
	_tmp452_ = g_strdup ("n");
	_tmp453_ = g_strdup ("modula2");
	_tmp454_ = g_strdup ("Modula 2");
	_tmp455_ = g_strdup ("");
	_tmp456_ = g_strdup ("n");
	_tmp457_ = g_strdup ("modula3");
	_tmp458_ = g_strdup ("Modula 3");
	_tmp459_ = g_strdup ("");
	_tmp460_ = g_strdup ("n");
	_tmp461_ = g_strdup ("68000devpac");
	_tmp462_ = g_strdup ("Motorola 68000 HiSoft Dev");
	_tmp463_ = g_strdup ("");
	_tmp464_ = g_strdup ("n");
	_tmp465_ = g_strdup ("mpasm");
	_tmp466_ = g_strdup ("MPASM");
	_tmp467_ = g_strdup ("");
	_tmp468_ = g_strdup ("n");
	_tmp469_ = g_strdup ("mxml");
	_tmp470_ = g_strdup ("MXML");
	_tmp471_ = g_strdup ("");
	_tmp472_ = g_strdup ("n");
	_tmp473_ = g_strdup ("mysql");
	_tmp474_ = g_strdup ("MySQL");
	_tmp475_ = g_strdup ("");
	_tmp476_ = g_strdup ("n");
	_tmp477_ = g_strdup ("newlisp");
	_tmp478_ = g_strdup ("newLISP");
	_tmp479_ = g_strdup ("");
	_tmp480_ = g_strdup ("n");
	_tmp481_ = g_strdup ("nsis");
	_tmp482_ = g_strdup ("NullSoft Installer");
	_tmp483_ = g_strdup ("");
	_tmp484_ = g_strdup ("n");
	_tmp485_ = g_strdup ("oberon2");
	_tmp486_ = g_strdup ("Oberon 2");
	_tmp487_ = g_strdup ("");
	_tmp488_ = g_strdup ("n");
	_tmp489_ = g_strdup ("objeck");
	_tmp490_ = g_strdup ("Objeck Programming Langua");
	_tmp491_ = g_strdup ("");
	_tmp492_ = g_strdup ("n");
	_tmp493_ = g_strdup ("objc");
	_tmp494_ = g_strdup ("Objective C");
	_tmp495_ = g_strdup ("objc");
	_tmp496_ = g_strdup ("n");
	_tmp497_ = g_strdup ("ocaml-brief");
	_tmp498_ = g_strdup ("OCalm Brief");
	_tmp499_ = g_strdup ("");
	_tmp500_ = g_strdup ("n");
	_tmp501_ = g_strdup ("ocaml");
	_tmp502_ = g_strdup ("OCaml");
	_tmp503_ = g_strdup ("");
	_tmp504_ = g_strdup ("n");
	_tmp505_ = g_strdup ("pf");
	_tmp506_ = g_strdup ("OpenBSD PACKET FILTER");
	_tmp507_ = g_strdup ("");
	_tmp508_ = g_strdup ("n");
	_tmp509_ = g_strdup ("glsl");
	_tmp510_ = g_strdup ("OpenGL Shading");
	_tmp511_ = g_strdup ("");
	_tmp512_ = g_strdup ("n");
	_tmp513_ = g_strdup ("oobas");
	_tmp514_ = g_strdup ("Openoffice BASIC");
	_tmp515_ = g_strdup ("");
	_tmp516_ = g_strdup ("n");
	_tmp517_ = g_strdup ("oracle11");
	_tmp518_ = g_strdup ("Oracle 11");
	_tmp519_ = g_strdup ("");
	_tmp520_ = g_strdup ("n");
	_tmp521_ = g_strdup ("oracle8");
	_tmp522_ = g_strdup ("Oracle 8");
	_tmp523_ = g_strdup ("");
	_tmp524_ = g_strdup ("n");
	_tmp525_ = g_strdup ("oz");
	_tmp526_ = g_strdup ("Oz");
	_tmp527_ = g_strdup ("");
	_tmp528_ = g_strdup ("n");
	_tmp529_ = g_strdup ("pascal");
	_tmp530_ = g_strdup ("Pascal");
	_tmp531_ = g_strdup ("pascal");
	_tmp532_ = g_strdup ("n");
	_tmp533_ = g_strdup ("pawn");
	_tmp534_ = g_strdup ("PAWN");
	_tmp535_ = g_strdup ("");
	_tmp536_ = g_strdup ("n");
	_tmp537_ = g_strdup ("pcre");
	_tmp538_ = g_strdup ("PCRE");
	_tmp539_ = g_strdup ("");
	_tmp540_ = g_strdup ("n");
	_tmp541_ = g_strdup ("per");
	_tmp542_ = g_strdup ("Per");
	_tmp543_ = g_strdup ("");
	_tmp544_ = g_strdup ("n");
	_tmp545_ = g_strdup ("perl");
	_tmp546_ = g_strdup ("Perl");
	_tmp547_ = g_strdup ("perl");
	_tmp548_ = g_strdup ("n");
	_tmp549_ = g_strdup ("perl6");
	_tmp550_ = g_strdup ("Perl 6");
	_tmp551_ = g_strdup ("");
	_tmp552_ = g_strdup ("n");
	_tmp553_ = g_strdup ("php");
	_tmp554_ = g_strdup ("PHP");
	_tmp555_ = g_strdup ("php");
	_tmp556_ = g_strdup ("n");
	_tmp557_ = g_strdup ("php-brief");
	_tmp558_ = g_strdup ("PHP Brief");
	_tmp559_ = g_strdup ("");
	_tmp560_ = g_strdup ("n");
	_tmp561_ = g_strdup ("pic16");
	_tmp562_ = g_strdup ("Pic 16");
	_tmp563_ = g_strdup ("");
	_tmp564_ = g_strdup ("n");
	_tmp565_ = g_strdup ("pike");
	_tmp566_ = g_strdup ("Pike");
	_tmp567_ = g_strdup ("");
	_tmp568_ = g_strdup ("n");
	_tmp569_ = g_strdup ("pixelbender");
	_tmp570_ = g_strdup ("Pixel Bender");
	_tmp571_ = g_strdup ("");
	_tmp572_ = g_strdup ("n");
	_tmp573_ = g_strdup ("plsql");
	_tmp574_ = g_strdup ("PL/SQL");
	_tmp575_ = g_strdup ("");
	_tmp576_ = g_strdup ("n");
	_tmp577_ = g_strdup ("postgresql");
	_tmp578_ = g_strdup ("PostgreSQL");
	_tmp579_ = g_strdup ("");
	_tmp580_ = g_strdup ("n");
	_tmp581_ = g_strdup ("povray");
	_tmp582_ = g_strdup ("POV-Ray");
	_tmp583_ = g_strdup ("");
	_tmp584_ = g_strdup ("n");
	_tmp585_ = g_strdup ("powershell");
	_tmp586_ = g_strdup ("Power Shell");
	_tmp587_ = g_strdup ("");
	_tmp588_ = g_strdup ("n");
	_tmp589_ = g_strdup ("powerbuilder");
	_tmp590_ = g_strdup ("PowerBuilder");
	_tmp591_ = g_strdup ("");
	_tmp592_ = g_strdup ("n");
	_tmp593_ = g_strdup ("proftpd");
	_tmp594_ = g_strdup ("ProFTPd");
	_tmp595_ = g_strdup ("");
	_tmp596_ = g_strdup ("n");
	_tmp597_ = g_strdup ("progress");
	_tmp598_ = g_strdup ("Progress");
	_tmp599_ = g_strdup ("");
	_tmp600_ = g_strdup ("n");
	_tmp601_ = g_strdup ("prolog");
	_tmp602_ = g_strdup ("Prolog");
	_tmp603_ = g_strdup ("");
	_tmp604_ = g_strdup ("n");
	_tmp605_ = g_strdup ("properties");
	_tmp606_ = g_strdup ("Properties");
	_tmp607_ = g_strdup ("");
	_tmp608_ = g_strdup ("n");
	_tmp609_ = g_strdup ("providex");
	_tmp610_ = g_strdup ("ProvideX");
	_tmp611_ = g_strdup ("");
	_tmp612_ = g_strdup ("n");
	_tmp613_ = g_strdup ("purebasic");
	_tmp614_ = g_strdup ("PureBasic");
	_tmp615_ = g_strdup ("");
	_tmp616_ = g_strdup ("n");
	_tmp617_ = g_strdup ("pycon");
	_tmp618_ = g_strdup ("PyCon");
	_tmp619_ = g_strdup ("");
	_tmp620_ = g_strdup ("n");
	_tmp621_ = g_strdup ("python");
	_tmp622_ = g_strdup ("Python");
	_tmp623_ = g_strdup ("python");
	_tmp624_ = g_strdup ("n");
	_tmp625_ = g_strdup ("q");
	_tmp626_ = g_strdup ("q/kdb+");
	_tmp627_ = g_strdup ("");
	_tmp628_ = g_strdup ("n");
	_tmp629_ = g_strdup ("qbasic");
	_tmp630_ = g_strdup ("QBasic");
	_tmp631_ = g_strdup ("");
	_tmp632_ = g_strdup ("n");
	_tmp633_ = g_strdup ("rsplus");
	_tmp634_ = g_strdup ("R");
	_tmp635_ = g_strdup ("");
	_tmp636_ = g_strdup ("n");
	_tmp637_ = g_strdup ("rails");
	_tmp638_ = g_strdup ("Rails");
	_tmp639_ = g_strdup ("");
	_tmp640_ = g_strdup ("n");
	_tmp641_ = g_strdup ("rebol");
	_tmp642_ = g_strdup ("REBOL");
	_tmp643_ = g_strdup ("");
	_tmp644_ = g_strdup ("n");
	_tmp645_ = g_strdup ("reg");
	_tmp646_ = g_strdup ("REG");
	_tmp647_ = g_strdup ("");
	_tmp648_ = g_strdup ("n");
	_tmp649_ = g_strdup ("robots");
	_tmp650_ = g_strdup ("Robots");
	_tmp651_ = g_strdup ("");
	_tmp652_ = g_strdup ("n");
	_tmp653_ = g_strdup ("rpmspec");
	_tmp654_ = g_strdup ("RPM Spec");
	_tmp655_ = g_strdup ("");
	_tmp656_ = g_strdup ("n");
	_tmp657_ = g_strdup ("ruby");
	_tmp658_ = g_strdup ("Ruby");
	_tmp659_ = g_strdup ("ruby");
	_tmp660_ = g_strdup ("n");
	_tmp661_ = g_strdup ("gnuplot");
	_tmp662_ = g_strdup ("Ruby Gnuplot");
	_tmp663_ = g_strdup ("");
	_tmp664_ = g_strdup ("n");
	_tmp665_ = g_strdup ("sas");
	_tmp666_ = g_strdup ("SAS");
	_tmp667_ = g_strdup ("");
	_tmp668_ = g_strdup ("n");
	_tmp669_ = g_strdup ("scala");
	_tmp670_ = g_strdup ("Scala");
	_tmp671_ = g_strdup ("");
	_tmp672_ = g_strdup ("n");
	_tmp673_ = g_strdup ("scheme");
	_tmp674_ = g_strdup ("Scheme");
	_tmp675_ = g_strdup ("");
	_tmp676_ = g_strdup ("n");
	_tmp677_ = g_strdup ("scilab");
	_tmp678_ = g_strdup ("Scilab");
	_tmp679_ = g_strdup ("");
	_tmp680_ = g_strdup ("n");
	_tmp681_ = g_strdup ("sdlbasic");
	_tmp682_ = g_strdup ("SdlBasic");
	_tmp683_ = g_strdup ("");
	_tmp684_ = g_strdup ("n");
	_tmp685_ = g_strdup ("smalltalk");
	_tmp686_ = g_strdup ("Smalltalk");
	_tmp687_ = g_strdup ("");
	_tmp688_ = g_strdup ("n");
	_tmp689_ = g_strdup ("smarty");
	_tmp690_ = g_strdup ("Smarty");
	_tmp691_ = g_strdup ("");
	_tmp692_ = g_strdup ("n");
	_tmp693_ = g_strdup ("sql");
	_tmp694_ = g_strdup ("SQL");
	_tmp695_ = g_strdup ("");
	_tmp696_ = g_strdup ("n");
	_tmp697_ = g_strdup ("systemverilog");
	_tmp698_ = g_strdup ("SystemVerilog");
	_tmp699_ = g_strdup ("");
	_tmp700_ = g_strdup ("n");
	_tmp701_ = g_strdup ("tsql");
	_tmp702_ = g_strdup ("T-SQL");
	_tmp703_ = g_strdup ("");
	_tmp704_ = g_strdup ("n");
	_tmp705_ = g_strdup ("tcl");
	_tmp706_ = g_strdup ("TCL");
	_tmp707_ = g_strdup ("");
	_tmp708_ = g_strdup ("n");
	_tmp709_ = g_strdup ("teraterm");
	_tmp710_ = g_strdup ("Tera Term");
	_tmp711_ = g_strdup ("");
	_tmp712_ = g_strdup ("n");
	_tmp713_ = g_strdup ("thinbasic");
	_tmp714_ = g_strdup ("thinBasic");
	_tmp715_ = g_strdup ("");
	_tmp716_ = g_strdup ("n");
	_tmp717_ = g_strdup ("typoscript");
	_tmp718_ = g_strdup ("TypoScript");
	_tmp719_ = g_strdup ("");
	_tmp720_ = g_strdup ("n");
	_tmp721_ = g_strdup ("unicon");
	_tmp722_ = g_strdup ("Unicon");
	_tmp723_ = g_strdup ("");
	_tmp724_ = g_strdup ("n");
	_tmp725_ = g_strdup ("uscript");
	_tmp726_ = g_strdup ("UnrealScript");
	_tmp727_ = g_strdup ("");
	_tmp728_ = g_strdup ("n");
	_tmp729_ = g_strdup ("vala");
	_tmp730_ = g_strdup ("Vala");
	_tmp731_ = g_strdup ("vala");
	_tmp732_ = g_strdup ("n");
	_tmp733_ = g_strdup ("vbnet");
	_tmp734_ = g_strdup ("VB.NET");
	_tmp735_ = g_strdup ("");
	_tmp736_ = g_strdup ("n");
	_tmp737_ = g_strdup ("verilog");
	_tmp738_ = g_strdup ("VeriLog");
	_tmp739_ = g_strdup ("");
	_tmp740_ = g_strdup ("n");
	_tmp741_ = g_strdup ("vhdl");
	_tmp742_ = g_strdup ("VHDL");
	_tmp743_ = g_strdup ("");
	_tmp744_ = g_strdup ("n");
	_tmp745_ = g_strdup ("vim");
	_tmp746_ = g_strdup ("VIM");
	_tmp747_ = g_strdup ("");
	_tmp748_ = g_strdup ("n");
	_tmp749_ = g_strdup ("visualprolog");
	_tmp750_ = g_strdup ("Visual Pro Log");
	_tmp751_ = g_strdup ("");
	_tmp752_ = g_strdup ("n");
	_tmp753_ = g_strdup ("vb");
	_tmp754_ = g_strdup ("VisualBasic");
	_tmp755_ = g_strdup ("");
	_tmp756_ = g_strdup ("n");
	_tmp757_ = g_strdup ("visualfoxpro");
	_tmp758_ = g_strdup ("VisualFoxPro");
	_tmp759_ = g_strdup ("");
	_tmp760_ = g_strdup ("n");
	_tmp761_ = g_strdup ("whitespace");
	_tmp762_ = g_strdup ("WhiteSpace");
	_tmp763_ = g_strdup ("");
	_tmp764_ = g_strdup ("n");
	_tmp765_ = g_strdup ("whois");
	_tmp766_ = g_strdup ("WHOIS");
	_tmp767_ = g_strdup ("");
	_tmp768_ = g_strdup ("n");
	_tmp769_ = g_strdup ("winbatch");
	_tmp770_ = g_strdup ("Winbatch");
	_tmp771_ = g_strdup ("");
	_tmp772_ = g_strdup ("n");
	_tmp773_ = g_strdup ("xbasic");
	_tmp774_ = g_strdup ("XBasic");
	_tmp775_ = g_strdup ("");
	_tmp776_ = g_strdup ("n");
	_tmp777_ = g_strdup ("xml");
	_tmp778_ = g_strdup ("XML");
	_tmp779_ = g_strdup ("xml");
	_tmp780_ = g_strdup ("n");
	_tmp781_ = g_strdup ("xorg_conf");
	_tmp782_ = g_strdup ("Xorg Config");
	_tmp783_ = g_strdup ("");
	_tmp784_ = g_strdup ("n");
	_tmp785_ = g_strdup ("xpp");
	_tmp786_ = g_strdup ("XPP");
	_tmp787_ = g_strdup ("");
	_tmp788_ = g_strdup ("n");
	_tmp789_ = g_strdup ("yaml");
	_tmp790_ = g_strdup ("YAML");
	_tmp791_ = g_strdup ("");
	_tmp792_ = g_strdup ("n");
	_tmp793_ = g_strdup ("z80");
	_tmp794_ = g_strdup ("Z80 Assembler");
	_tmp795_ = g_strdup ("");
	_tmp796_ = g_strdup ("n");
	_tmp797_ = g_strdup ("zxbasic");
	_tmp798_ = g_strdup ("ZXBasic");
	_tmp799_ = g_strdup ("");
	_tmp800_ = g_new0 (gchar*, (200 * 4) + 1);
	_tmp800_[0] = _tmp0_;
	_tmp800_[1] = _tmp1_;
	_tmp800_[2] = _tmp2_;
	_tmp800_[3] = _tmp3_;
	_tmp800_[4] = _tmp4_;
	_tmp800_[5] = _tmp5_;
	_tmp800_[6] = _tmp6_;
	_tmp800_[7] = _tmp7_;
	_tmp800_[8] = _tmp8_;
	_tmp800_[9] = _tmp9_;
	_tmp800_[10] = _tmp10_;
	_tmp800_[11] = _tmp11_;
	_tmp800_[12] = _tmp12_;
	_tmp800_[13] = _tmp13_;
	_tmp800_[14] = _tmp14_;
	_tmp800_[15] = _tmp15_;
	_tmp800_[16] = _tmp16_;
	_tmp800_[17] = _tmp17_;
	_tmp800_[18] = _tmp18_;
	_tmp800_[19] = _tmp19_;
	_tmp800_[20] = _tmp20_;
	_tmp800_[21] = _tmp21_;
	_tmp800_[22] = _tmp22_;
	_tmp800_[23] = _tmp23_;
	_tmp800_[24] = _tmp24_;
	_tmp800_[25] = _tmp25_;
	_tmp800_[26] = _tmp26_;
	_tmp800_[27] = _tmp27_;
	_tmp800_[28] = _tmp28_;
	_tmp800_[29] = _tmp29_;
	_tmp800_[30] = _tmp30_;
	_tmp800_[31] = _tmp31_;
	_tmp800_[32] = _tmp32_;
	_tmp800_[33] = _tmp33_;
	_tmp800_[34] = _tmp34_;
	_tmp800_[35] = _tmp35_;
	_tmp800_[36] = _tmp36_;
	_tmp800_[37] = _tmp37_;
	_tmp800_[38] = _tmp38_;
	_tmp800_[39] = _tmp39_;
	_tmp800_[40] = _tmp40_;
	_tmp800_[41] = _tmp41_;
	_tmp800_[42] = _tmp42_;
	_tmp800_[43] = _tmp43_;
	_tmp800_[44] = _tmp44_;
	_tmp800_[45] = _tmp45_;
	_tmp800_[46] = _tmp46_;
	_tmp800_[47] = _tmp47_;
	_tmp800_[48] = _tmp48_;
	_tmp800_[49] = _tmp49_;
	_tmp800_[50] = _tmp50_;
	_tmp800_[51] = _tmp51_;
	_tmp800_[52] = _tmp52_;
	_tmp800_[53] = _tmp53_;
	_tmp800_[54] = _tmp54_;
	_tmp800_[55] = _tmp55_;
	_tmp800_[56] = _tmp56_;
	_tmp800_[57] = _tmp57_;
	_tmp800_[58] = _tmp58_;
	_tmp800_[59] = _tmp59_;
	_tmp800_[60] = _tmp60_;
	_tmp800_[61] = _tmp61_;
	_tmp800_[62] = _tmp62_;
	_tmp800_[63] = _tmp63_;
	_tmp800_[64] = _tmp64_;
	_tmp800_[65] = _tmp65_;
	_tmp800_[66] = _tmp66_;
	_tmp800_[67] = _tmp67_;
	_tmp800_[68] = _tmp68_;
	_tmp800_[69] = _tmp69_;
	_tmp800_[70] = _tmp70_;
	_tmp800_[71] = _tmp71_;
	_tmp800_[72] = _tmp72_;
	_tmp800_[73] = _tmp73_;
	_tmp800_[74] = _tmp74_;
	_tmp800_[75] = _tmp75_;
	_tmp800_[76] = _tmp76_;
	_tmp800_[77] = _tmp77_;
	_tmp800_[78] = _tmp78_;
	_tmp800_[79] = _tmp79_;
	_tmp800_[80] = _tmp80_;
	_tmp800_[81] = _tmp81_;
	_tmp800_[82] = _tmp82_;
	_tmp800_[83] = _tmp83_;
	_tmp800_[84] = _tmp84_;
	_tmp800_[85] = _tmp85_;
	_tmp800_[86] = _tmp86_;
	_tmp800_[87] = _tmp87_;
	_tmp800_[88] = _tmp88_;
	_tmp800_[89] = _tmp89_;
	_tmp800_[90] = _tmp90_;
	_tmp800_[91] = _tmp91_;
	_tmp800_[92] = _tmp92_;
	_tmp800_[93] = _tmp93_;
	_tmp800_[94] = _tmp94_;
	_tmp800_[95] = _tmp95_;
	_tmp800_[96] = _tmp96_;
	_tmp800_[97] = _tmp97_;
	_tmp800_[98] = _tmp98_;
	_tmp800_[99] = _tmp99_;
	_tmp800_[100] = _tmp100_;
	_tmp800_[101] = _tmp101_;
	_tmp800_[102] = _tmp102_;
	_tmp800_[103] = _tmp103_;
	_tmp800_[104] = _tmp104_;
	_tmp800_[105] = _tmp105_;
	_tmp800_[106] = _tmp106_;
	_tmp800_[107] = _tmp107_;
	_tmp800_[108] = _tmp108_;
	_tmp800_[109] = _tmp109_;
	_tmp800_[110] = _tmp110_;
	_tmp800_[111] = _tmp111_;
	_tmp800_[112] = _tmp112_;
	_tmp800_[113] = _tmp113_;
	_tmp800_[114] = _tmp114_;
	_tmp800_[115] = _tmp115_;
	_tmp800_[116] = _tmp116_;
	_tmp800_[117] = _tmp117_;
	_tmp800_[118] = _tmp118_;
	_tmp800_[119] = _tmp119_;
	_tmp800_[120] = _tmp120_;
	_tmp800_[121] = _tmp121_;
	_tmp800_[122] = _tmp122_;
	_tmp800_[123] = _tmp123_;
	_tmp800_[124] = _tmp124_;
	_tmp800_[125] = _tmp125_;
	_tmp800_[126] = _tmp126_;
	_tmp800_[127] = _tmp127_;
	_tmp800_[128] = _tmp128_;
	_tmp800_[129] = _tmp129_;
	_tmp800_[130] = _tmp130_;
	_tmp800_[131] = _tmp131_;
	_tmp800_[132] = _tmp132_;
	_tmp800_[133] = _tmp133_;
	_tmp800_[134] = _tmp134_;
	_tmp800_[135] = _tmp135_;
	_tmp800_[136] = _tmp136_;
	_tmp800_[137] = _tmp137_;
	_tmp800_[138] = _tmp138_;
	_tmp800_[139] = _tmp139_;
	_tmp800_[140] = _tmp140_;
	_tmp800_[141] = _tmp141_;
	_tmp800_[142] = _tmp142_;
	_tmp800_[143] = _tmp143_;
	_tmp800_[144] = _tmp144_;
	_tmp800_[145] = _tmp145_;
	_tmp800_[146] = _tmp146_;
	_tmp800_[147] = _tmp147_;
	_tmp800_[148] = _tmp148_;
	_tmp800_[149] = _tmp149_;
	_tmp800_[150] = _tmp150_;
	_tmp800_[151] = _tmp151_;
	_tmp800_[152] = _tmp152_;
	_tmp800_[153] = _tmp153_;
	_tmp800_[154] = _tmp154_;
	_tmp800_[155] = _tmp155_;
	_tmp800_[156] = _tmp156_;
	_tmp800_[157] = _tmp157_;
	_tmp800_[158] = _tmp158_;
	_tmp800_[159] = _tmp159_;
	_tmp800_[160] = _tmp160_;
	_tmp800_[161] = _tmp161_;
	_tmp800_[162] = _tmp162_;
	_tmp800_[163] = _tmp163_;
	_tmp800_[164] = _tmp164_;
	_tmp800_[165] = _tmp165_;
	_tmp800_[166] = _tmp166_;
	_tmp800_[167] = _tmp167_;
	_tmp800_[168] = _tmp168_;
	_tmp800_[169] = _tmp169_;
	_tmp800_[170] = _tmp170_;
	_tmp800_[171] = _tmp171_;
	_tmp800_[172] = _tmp172_;
	_tmp800_[173] = _tmp173_;
	_tmp800_[174] = _tmp174_;
	_tmp800_[175] = _tmp175_;
	_tmp800_[176] = _tmp176_;
	_tmp800_[177] = _tmp177_;
	_tmp800_[178] = _tmp178_;
	_tmp800_[179] = _tmp179_;
	_tmp800_[180] = _tmp180_;
	_tmp800_[181] = _tmp181_;
	_tmp800_[182] = _tmp182_;
	_tmp800_[183] = _tmp183_;
	_tmp800_[184] = _tmp184_;
	_tmp800_[185] = _tmp185_;
	_tmp800_[186] = _tmp186_;
	_tmp800_[187] = _tmp187_;
	_tmp800_[188] = _tmp188_;
	_tmp800_[189] = _tmp189_;
	_tmp800_[190] = _tmp190_;
	_tmp800_[191] = _tmp191_;
	_tmp800_[192] = _tmp192_;
	_tmp800_[193] = _tmp193_;
	_tmp800_[194] = _tmp194_;
	_tmp800_[195] = _tmp195_;
	_tmp800_[196] = _tmp196_;
	_tmp800_[197] = _tmp197_;
	_tmp800_[198] = _tmp198_;
	_tmp800_[199] = _tmp199_;
	_tmp800_[200] = _tmp200_;
	_tmp800_[201] = _tmp201_;
	_tmp800_[202] = _tmp202_;
	_tmp800_[203] = _tmp203_;
	_tmp800_[204] = _tmp204_;
	_tmp800_[205] = _tmp205_;
	_tmp800_[206] = _tmp206_;
	_tmp800_[207] = _tmp207_;
	_tmp800_[208] = _tmp208_;
	_tmp800_[209] = _tmp209_;
	_tmp800_[210] = _tmp210_;
	_tmp800_[211] = _tmp211_;
	_tmp800_[212] = _tmp212_;
	_tmp800_[213] = _tmp213_;
	_tmp800_[214] = _tmp214_;
	_tmp800_[215] = _tmp215_;
	_tmp800_[216] = _tmp216_;
	_tmp800_[217] = _tmp217_;
	_tmp800_[218] = _tmp218_;
	_tmp800_[219] = _tmp219_;
	_tmp800_[220] = _tmp220_;
	_tmp800_[221] = _tmp221_;
	_tmp800_[222] = _tmp222_;
	_tmp800_[223] = _tmp223_;
	_tmp800_[224] = _tmp224_;
	_tmp800_[225] = _tmp225_;
	_tmp800_[226] = _tmp226_;
	_tmp800_[227] = _tmp227_;
	_tmp800_[228] = _tmp228_;
	_tmp800_[229] = _tmp229_;
	_tmp800_[230] = _tmp230_;
	_tmp800_[231] = _tmp231_;
	_tmp800_[232] = _tmp232_;
	_tmp800_[233] = _tmp233_;
	_tmp800_[234] = _tmp234_;
	_tmp800_[235] = _tmp235_;
	_tmp800_[236] = _tmp236_;
	_tmp800_[237] = _tmp237_;
	_tmp800_[238] = _tmp238_;
	_tmp800_[239] = _tmp239_;
	_tmp800_[240] = _tmp240_;
	_tmp800_[241] = _tmp241_;
	_tmp800_[242] = _tmp242_;
	_tmp800_[243] = _tmp243_;
	_tmp800_[244] = _tmp244_;
	_tmp800_[245] = _tmp245_;
	_tmp800_[246] = _tmp246_;
	_tmp800_[247] = _tmp247_;
	_tmp800_[248] = _tmp248_;
	_tmp800_[249] = _tmp249_;
	_tmp800_[250] = _tmp250_;
	_tmp800_[251] = _tmp251_;
	_tmp800_[252] = _tmp252_;
	_tmp800_[253] = _tmp253_;
	_tmp800_[254] = _tmp254_;
	_tmp800_[255] = _tmp255_;
	_tmp800_[256] = _tmp256_;
	_tmp800_[257] = _tmp257_;
	_tmp800_[258] = _tmp258_;
	_tmp800_[259] = _tmp259_;
	_tmp800_[260] = _tmp260_;
	_tmp800_[261] = _tmp261_;
	_tmp800_[262] = _tmp262_;
	_tmp800_[263] = _tmp263_;
	_tmp800_[264] = _tmp264_;
	_tmp800_[265] = _tmp265_;
	_tmp800_[266] = _tmp266_;
	_tmp800_[267] = _tmp267_;
	_tmp800_[268] = _tmp268_;
	_tmp800_[269] = _tmp269_;
	_tmp800_[270] = _tmp270_;
	_tmp800_[271] = _tmp271_;
	_tmp800_[272] = _tmp272_;
	_tmp800_[273] = _tmp273_;
	_tmp800_[274] = _tmp274_;
	_tmp800_[275] = _tmp275_;
	_tmp800_[276] = _tmp276_;
	_tmp800_[277] = _tmp277_;
	_tmp800_[278] = _tmp278_;
	_tmp800_[279] = _tmp279_;
	_tmp800_[280] = _tmp280_;
	_tmp800_[281] = _tmp281_;
	_tmp800_[282] = _tmp282_;
	_tmp800_[283] = _tmp283_;
	_tmp800_[284] = _tmp284_;
	_tmp800_[285] = _tmp285_;
	_tmp800_[286] = _tmp286_;
	_tmp800_[287] = _tmp287_;
	_tmp800_[288] = _tmp288_;
	_tmp800_[289] = _tmp289_;
	_tmp800_[290] = _tmp290_;
	_tmp800_[291] = _tmp291_;
	_tmp800_[292] = _tmp292_;
	_tmp800_[293] = _tmp293_;
	_tmp800_[294] = _tmp294_;
	_tmp800_[295] = _tmp295_;
	_tmp800_[296] = _tmp296_;
	_tmp800_[297] = _tmp297_;
	_tmp800_[298] = _tmp298_;
	_tmp800_[299] = _tmp299_;
	_tmp800_[300] = _tmp300_;
	_tmp800_[301] = _tmp301_;
	_tmp800_[302] = _tmp302_;
	_tmp800_[303] = _tmp303_;
	_tmp800_[304] = _tmp304_;
	_tmp800_[305] = _tmp305_;
	_tmp800_[306] = _tmp306_;
	_tmp800_[307] = _tmp307_;
	_tmp800_[308] = _tmp308_;
	_tmp800_[309] = _tmp309_;
	_tmp800_[310] = _tmp310_;
	_tmp800_[311] = _tmp311_;
	_tmp800_[312] = _tmp312_;
	_tmp800_[313] = _tmp313_;
	_tmp800_[314] = _tmp314_;
	_tmp800_[315] = _tmp315_;
	_tmp800_[316] = _tmp316_;
	_tmp800_[317] = _tmp317_;
	_tmp800_[318] = _tmp318_;
	_tmp800_[319] = _tmp319_;
	_tmp800_[320] = _tmp320_;
	_tmp800_[321] = _tmp321_;
	_tmp800_[322] = _tmp322_;
	_tmp800_[323] = _tmp323_;
	_tmp800_[324] = _tmp324_;
	_tmp800_[325] = _tmp325_;
	_tmp800_[326] = _tmp326_;
	_tmp800_[327] = _tmp327_;
	_tmp800_[328] = _tmp328_;
	_tmp800_[329] = _tmp329_;
	_tmp800_[330] = _tmp330_;
	_tmp800_[331] = _tmp331_;
	_tmp800_[332] = _tmp332_;
	_tmp800_[333] = _tmp333_;
	_tmp800_[334] = _tmp334_;
	_tmp800_[335] = _tmp335_;
	_tmp800_[336] = _tmp336_;
	_tmp800_[337] = _tmp337_;
	_tmp800_[338] = _tmp338_;
	_tmp800_[339] = _tmp339_;
	_tmp800_[340] = _tmp340_;
	_tmp800_[341] = _tmp341_;
	_tmp800_[342] = _tmp342_;
	_tmp800_[343] = _tmp343_;
	_tmp800_[344] = _tmp344_;
	_tmp800_[345] = _tmp345_;
	_tmp800_[346] = _tmp346_;
	_tmp800_[347] = _tmp347_;
	_tmp800_[348] = _tmp348_;
	_tmp800_[349] = _tmp349_;
	_tmp800_[350] = _tmp350_;
	_tmp800_[351] = _tmp351_;
	_tmp800_[352] = _tmp352_;
	_tmp800_[353] = _tmp353_;
	_tmp800_[354] = _tmp354_;
	_tmp800_[355] = _tmp355_;
	_tmp800_[356] = _tmp356_;
	_tmp800_[357] = _tmp357_;
	_tmp800_[358] = _tmp358_;
	_tmp800_[359] = _tmp359_;
	_tmp800_[360] = _tmp360_;
	_tmp800_[361] = _tmp361_;
	_tmp800_[362] = _tmp362_;
	_tmp800_[363] = _tmp363_;
	_tmp800_[364] = _tmp364_;
	_tmp800_[365] = _tmp365_;
	_tmp800_[366] = _tmp366_;
	_tmp800_[367] = _tmp367_;
	_tmp800_[368] = _tmp368_;
	_tmp800_[369] = _tmp369_;
	_tmp800_[370] = _tmp370_;
	_tmp800_[371] = _tmp371_;
	_tmp800_[372] = _tmp372_;
	_tmp800_[373] = _tmp373_;
	_tmp800_[374] = _tmp374_;
	_tmp800_[375] = _tmp375_;
	_tmp800_[376] = _tmp376_;
	_tmp800_[377] = _tmp377_;
	_tmp800_[378] = _tmp378_;
	_tmp800_[379] = _tmp379_;
	_tmp800_[380] = _tmp380_;
	_tmp800_[381] = _tmp381_;
	_tmp800_[382] = _tmp382_;
	_tmp800_[383] = _tmp383_;
	_tmp800_[384] = _tmp384_;
	_tmp800_[385] = _tmp385_;
	_tmp800_[386] = _tmp386_;
	_tmp800_[387] = _tmp387_;
	_tmp800_[388] = _tmp388_;
	_tmp800_[389] = _tmp389_;
	_tmp800_[390] = _tmp390_;
	_tmp800_[391] = _tmp391_;
	_tmp800_[392] = _tmp392_;
	_tmp800_[393] = _tmp393_;
	_tmp800_[394] = _tmp394_;
	_tmp800_[395] = _tmp395_;
	_tmp800_[396] = _tmp396_;
	_tmp800_[397] = _tmp397_;
	_tmp800_[398] = _tmp398_;
	_tmp800_[399] = _tmp399_;
	_tmp800_[400] = _tmp400_;
	_tmp800_[401] = _tmp401_;
	_tmp800_[402] = _tmp402_;
	_tmp800_[403] = _tmp403_;
	_tmp800_[404] = _tmp404_;
	_tmp800_[405] = _tmp405_;
	_tmp800_[406] = _tmp406_;
	_tmp800_[407] = _tmp407_;
	_tmp800_[408] = _tmp408_;
	_tmp800_[409] = _tmp409_;
	_tmp800_[410] = _tmp410_;
	_tmp800_[411] = _tmp411_;
	_tmp800_[412] = _tmp412_;
	_tmp800_[413] = _tmp413_;
	_tmp800_[414] = _tmp414_;
	_tmp800_[415] = _tmp415_;
	_tmp800_[416] = _tmp416_;
	_tmp800_[417] = _tmp417_;
	_tmp800_[418] = _tmp418_;
	_tmp800_[419] = _tmp419_;
	_tmp800_[420] = _tmp420_;
	_tmp800_[421] = _tmp421_;
	_tmp800_[422] = _tmp422_;
	_tmp800_[423] = _tmp423_;
	_tmp800_[424] = _tmp424_;
	_tmp800_[425] = _tmp425_;
	_tmp800_[426] = _tmp426_;
	_tmp800_[427] = _tmp427_;
	_tmp800_[428] = _tmp428_;
	_tmp800_[429] = _tmp429_;
	_tmp800_[430] = _tmp430_;
	_tmp800_[431] = _tmp431_;
	_tmp800_[432] = _tmp432_;
	_tmp800_[433] = _tmp433_;
	_tmp800_[434] = _tmp434_;
	_tmp800_[435] = _tmp435_;
	_tmp800_[436] = _tmp436_;
	_tmp800_[437] = _tmp437_;
	_tmp800_[438] = _tmp438_;
	_tmp800_[439] = _tmp439_;
	_tmp800_[440] = _tmp440_;
	_tmp800_[441] = _tmp441_;
	_tmp800_[442] = _tmp442_;
	_tmp800_[443] = _tmp443_;
	_tmp800_[444] = _tmp444_;
	_tmp800_[445] = _tmp445_;
	_tmp800_[446] = _tmp446_;
	_tmp800_[447] = _tmp447_;
	_tmp800_[448] = _tmp448_;
	_tmp800_[449] = _tmp449_;
	_tmp800_[450] = _tmp450_;
	_tmp800_[451] = _tmp451_;
	_tmp800_[452] = _tmp452_;
	_tmp800_[453] = _tmp453_;
	_tmp800_[454] = _tmp454_;
	_tmp800_[455] = _tmp455_;
	_tmp800_[456] = _tmp456_;
	_tmp800_[457] = _tmp457_;
	_tmp800_[458] = _tmp458_;
	_tmp800_[459] = _tmp459_;
	_tmp800_[460] = _tmp460_;
	_tmp800_[461] = _tmp461_;
	_tmp800_[462] = _tmp462_;
	_tmp800_[463] = _tmp463_;
	_tmp800_[464] = _tmp464_;
	_tmp800_[465] = _tmp465_;
	_tmp800_[466] = _tmp466_;
	_tmp800_[467] = _tmp467_;
	_tmp800_[468] = _tmp468_;
	_tmp800_[469] = _tmp469_;
	_tmp800_[470] = _tmp470_;
	_tmp800_[471] = _tmp471_;
	_tmp800_[472] = _tmp472_;
	_tmp800_[473] = _tmp473_;
	_tmp800_[474] = _tmp474_;
	_tmp800_[475] = _tmp475_;
	_tmp800_[476] = _tmp476_;
	_tmp800_[477] = _tmp477_;
	_tmp800_[478] = _tmp478_;
	_tmp800_[479] = _tmp479_;
	_tmp800_[480] = _tmp480_;
	_tmp800_[481] = _tmp481_;
	_tmp800_[482] = _tmp482_;
	_tmp800_[483] = _tmp483_;
	_tmp800_[484] = _tmp484_;
	_tmp800_[485] = _tmp485_;
	_tmp800_[486] = _tmp486_;
	_tmp800_[487] = _tmp487_;
	_tmp800_[488] = _tmp488_;
	_tmp800_[489] = _tmp489_;
	_tmp800_[490] = _tmp490_;
	_tmp800_[491] = _tmp491_;
	_tmp800_[492] = _tmp492_;
	_tmp800_[493] = _tmp493_;
	_tmp800_[494] = _tmp494_;
	_tmp800_[495] = _tmp495_;
	_tmp800_[496] = _tmp496_;
	_tmp800_[497] = _tmp497_;
	_tmp800_[498] = _tmp498_;
	_tmp800_[499] = _tmp499_;
	_tmp800_[500] = _tmp500_;
	_tmp800_[501] = _tmp501_;
	_tmp800_[502] = _tmp502_;
	_tmp800_[503] = _tmp503_;
	_tmp800_[504] = _tmp504_;
	_tmp800_[505] = _tmp505_;
	_tmp800_[506] = _tmp506_;
	_tmp800_[507] = _tmp507_;
	_tmp800_[508] = _tmp508_;
	_tmp800_[509] = _tmp509_;
	_tmp800_[510] = _tmp510_;
	_tmp800_[511] = _tmp511_;
	_tmp800_[512] = _tmp512_;
	_tmp800_[513] = _tmp513_;
	_tmp800_[514] = _tmp514_;
	_tmp800_[515] = _tmp515_;
	_tmp800_[516] = _tmp516_;
	_tmp800_[517] = _tmp517_;
	_tmp800_[518] = _tmp518_;
	_tmp800_[519] = _tmp519_;
	_tmp800_[520] = _tmp520_;
	_tmp800_[521] = _tmp521_;
	_tmp800_[522] = _tmp522_;
	_tmp800_[523] = _tmp523_;
	_tmp800_[524] = _tmp524_;
	_tmp800_[525] = _tmp525_;
	_tmp800_[526] = _tmp526_;
	_tmp800_[527] = _tmp527_;
	_tmp800_[528] = _tmp528_;
	_tmp800_[529] = _tmp529_;
	_tmp800_[530] = _tmp530_;
	_tmp800_[531] = _tmp531_;
	_tmp800_[532] = _tmp532_;
	_tmp800_[533] = _tmp533_;
	_tmp800_[534] = _tmp534_;
	_tmp800_[535] = _tmp535_;
	_tmp800_[536] = _tmp536_;
	_tmp800_[537] = _tmp537_;
	_tmp800_[538] = _tmp538_;
	_tmp800_[539] = _tmp539_;
	_tmp800_[540] = _tmp540_;
	_tmp800_[541] = _tmp541_;
	_tmp800_[542] = _tmp542_;
	_tmp800_[543] = _tmp543_;
	_tmp800_[544] = _tmp544_;
	_tmp800_[545] = _tmp545_;
	_tmp800_[546] = _tmp546_;
	_tmp800_[547] = _tmp547_;
	_tmp800_[548] = _tmp548_;
	_tmp800_[549] = _tmp549_;
	_tmp800_[550] = _tmp550_;
	_tmp800_[551] = _tmp551_;
	_tmp800_[552] = _tmp552_;
	_tmp800_[553] = _tmp553_;
	_tmp800_[554] = _tmp554_;
	_tmp800_[555] = _tmp555_;
	_tmp800_[556] = _tmp556_;
	_tmp800_[557] = _tmp557_;
	_tmp800_[558] = _tmp558_;
	_tmp800_[559] = _tmp559_;
	_tmp800_[560] = _tmp560_;
	_tmp800_[561] = _tmp561_;
	_tmp800_[562] = _tmp562_;
	_tmp800_[563] = _tmp563_;
	_tmp800_[564] = _tmp564_;
	_tmp800_[565] = _tmp565_;
	_tmp800_[566] = _tmp566_;
	_tmp800_[567] = _tmp567_;
	_tmp800_[568] = _tmp568_;
	_tmp800_[569] = _tmp569_;
	_tmp800_[570] = _tmp570_;
	_tmp800_[571] = _tmp571_;
	_tmp800_[572] = _tmp572_;
	_tmp800_[573] = _tmp573_;
	_tmp800_[574] = _tmp574_;
	_tmp800_[575] = _tmp575_;
	_tmp800_[576] = _tmp576_;
	_tmp800_[577] = _tmp577_;
	_tmp800_[578] = _tmp578_;
	_tmp800_[579] = _tmp579_;
	_tmp800_[580] = _tmp580_;
	_tmp800_[581] = _tmp581_;
	_tmp800_[582] = _tmp582_;
	_tmp800_[583] = _tmp583_;
	_tmp800_[584] = _tmp584_;
	_tmp800_[585] = _tmp585_;
	_tmp800_[586] = _tmp586_;
	_tmp800_[587] = _tmp587_;
	_tmp800_[588] = _tmp588_;
	_tmp800_[589] = _tmp589_;
	_tmp800_[590] = _tmp590_;
	_tmp800_[591] = _tmp591_;
	_tmp800_[592] = _tmp592_;
	_tmp800_[593] = _tmp593_;
	_tmp800_[594] = _tmp594_;
	_tmp800_[595] = _tmp595_;
	_tmp800_[596] = _tmp596_;
	_tmp800_[597] = _tmp597_;
	_tmp800_[598] = _tmp598_;
	_tmp800_[599] = _tmp599_;
	_tmp800_[600] = _tmp600_;
	_tmp800_[601] = _tmp601_;
	_tmp800_[602] = _tmp602_;
	_tmp800_[603] = _tmp603_;
	_tmp800_[604] = _tmp604_;
	_tmp800_[605] = _tmp605_;
	_tmp800_[606] = _tmp606_;
	_tmp800_[607] = _tmp607_;
	_tmp800_[608] = _tmp608_;
	_tmp800_[609] = _tmp609_;
	_tmp800_[610] = _tmp610_;
	_tmp800_[611] = _tmp611_;
	_tmp800_[612] = _tmp612_;
	_tmp800_[613] = _tmp613_;
	_tmp800_[614] = _tmp614_;
	_tmp800_[615] = _tmp615_;
	_tmp800_[616] = _tmp616_;
	_tmp800_[617] = _tmp617_;
	_tmp800_[618] = _tmp618_;
	_tmp800_[619] = _tmp619_;
	_tmp800_[620] = _tmp620_;
	_tmp800_[621] = _tmp621_;
	_tmp800_[622] = _tmp622_;
	_tmp800_[623] = _tmp623_;
	_tmp800_[624] = _tmp624_;
	_tmp800_[625] = _tmp625_;
	_tmp800_[626] = _tmp626_;
	_tmp800_[627] = _tmp627_;
	_tmp800_[628] = _tmp628_;
	_tmp800_[629] = _tmp629_;
	_tmp800_[630] = _tmp630_;
	_tmp800_[631] = _tmp631_;
	_tmp800_[632] = _tmp632_;
	_tmp800_[633] = _tmp633_;
	_tmp800_[634] = _tmp634_;
	_tmp800_[635] = _tmp635_;
	_tmp800_[636] = _tmp636_;
	_tmp800_[637] = _tmp637_;
	_tmp800_[638] = _tmp638_;
	_tmp800_[639] = _tmp639_;
	_tmp800_[640] = _tmp640_;
	_tmp800_[641] = _tmp641_;
	_tmp800_[642] = _tmp642_;
	_tmp800_[643] = _tmp643_;
	_tmp800_[644] = _tmp644_;
	_tmp800_[645] = _tmp645_;
	_tmp800_[646] = _tmp646_;
	_tmp800_[647] = _tmp647_;
	_tmp800_[648] = _tmp648_;
	_tmp800_[649] = _tmp649_;
	_tmp800_[650] = _tmp650_;
	_tmp800_[651] = _tmp651_;
	_tmp800_[652] = _tmp652_;
	_tmp800_[653] = _tmp653_;
	_tmp800_[654] = _tmp654_;
	_tmp800_[655] = _tmp655_;
	_tmp800_[656] = _tmp656_;
	_tmp800_[657] = _tmp657_;
	_tmp800_[658] = _tmp658_;
	_tmp800_[659] = _tmp659_;
	_tmp800_[660] = _tmp660_;
	_tmp800_[661] = _tmp661_;
	_tmp800_[662] = _tmp662_;
	_tmp800_[663] = _tmp663_;
	_tmp800_[664] = _tmp664_;
	_tmp800_[665] = _tmp665_;
	_tmp800_[666] = _tmp666_;
	_tmp800_[667] = _tmp667_;
	_tmp800_[668] = _tmp668_;
	_tmp800_[669] = _tmp669_;
	_tmp800_[670] = _tmp670_;
	_tmp800_[671] = _tmp671_;
	_tmp800_[672] = _tmp672_;
	_tmp800_[673] = _tmp673_;
	_tmp800_[674] = _tmp674_;
	_tmp800_[675] = _tmp675_;
	_tmp800_[676] = _tmp676_;
	_tmp800_[677] = _tmp677_;
	_tmp800_[678] = _tmp678_;
	_tmp800_[679] = _tmp679_;
	_tmp800_[680] = _tmp680_;
	_tmp800_[681] = _tmp681_;
	_tmp800_[682] = _tmp682_;
	_tmp800_[683] = _tmp683_;
	_tmp800_[684] = _tmp684_;
	_tmp800_[685] = _tmp685_;
	_tmp800_[686] = _tmp686_;
	_tmp800_[687] = _tmp687_;
	_tmp800_[688] = _tmp688_;
	_tmp800_[689] = _tmp689_;
	_tmp800_[690] = _tmp690_;
	_tmp800_[691] = _tmp691_;
	_tmp800_[692] = _tmp692_;
	_tmp800_[693] = _tmp693_;
	_tmp800_[694] = _tmp694_;
	_tmp800_[695] = _tmp695_;
	_tmp800_[696] = _tmp696_;
	_tmp800_[697] = _tmp697_;
	_tmp800_[698] = _tmp698_;
	_tmp800_[699] = _tmp699_;
	_tmp800_[700] = _tmp700_;
	_tmp800_[701] = _tmp701_;
	_tmp800_[702] = _tmp702_;
	_tmp800_[703] = _tmp703_;
	_tmp800_[704] = _tmp704_;
	_tmp800_[705] = _tmp705_;
	_tmp800_[706] = _tmp706_;
	_tmp800_[707] = _tmp707_;
	_tmp800_[708] = _tmp708_;
	_tmp800_[709] = _tmp709_;
	_tmp800_[710] = _tmp710_;
	_tmp800_[711] = _tmp711_;
	_tmp800_[712] = _tmp712_;
	_tmp800_[713] = _tmp713_;
	_tmp800_[714] = _tmp714_;
	_tmp800_[715] = _tmp715_;
	_tmp800_[716] = _tmp716_;
	_tmp800_[717] = _tmp717_;
	_tmp800_[718] = _tmp718_;
	_tmp800_[719] = _tmp719_;
	_tmp800_[720] = _tmp720_;
	_tmp800_[721] = _tmp721_;
	_tmp800_[722] = _tmp722_;
	_tmp800_[723] = _tmp723_;
	_tmp800_[724] = _tmp724_;
	_tmp800_[725] = _tmp725_;
	_tmp800_[726] = _tmp726_;
	_tmp800_[727] = _tmp727_;
	_tmp800_[728] = _tmp728_;
	_tmp800_[729] = _tmp729_;
	_tmp800_[730] = _tmp730_;
	_tmp800_[731] = _tmp731_;
	_tmp800_[732] = _tmp732_;
	_tmp800_[733] = _tmp733_;
	_tmp800_[734] = _tmp734_;
	_tmp800_[735] = _tmp735_;
	_tmp800_[736] = _tmp736_;
	_tmp800_[737] = _tmp737_;
	_tmp800_[738] = _tmp738_;
	_tmp800_[739] = _tmp739_;
	_tmp800_[740] = _tmp740_;
	_tmp800_[741] = _tmp741_;
	_tmp800_[742] = _tmp742_;
	_tmp800_[743] = _tmp743_;
	_tmp800_[744] = _tmp744_;
	_tmp800_[745] = _tmp745_;
	_tmp800_[746] = _tmp746_;
	_tmp800_[747] = _tmp747_;
	_tmp800_[748] = _tmp748_;
	_tmp800_[749] = _tmp749_;
	_tmp800_[750] = _tmp750_;
	_tmp800_[751] = _tmp751_;
	_tmp800_[752] = _tmp752_;
	_tmp800_[753] = _tmp753_;
	_tmp800_[754] = _tmp754_;
	_tmp800_[755] = _tmp755_;
	_tmp800_[756] = _tmp756_;
	_tmp800_[757] = _tmp757_;
	_tmp800_[758] = _tmp758_;
	_tmp800_[759] = _tmp759_;
	_tmp800_[760] = _tmp760_;
	_tmp800_[761] = _tmp761_;
	_tmp800_[762] = _tmp762_;
	_tmp800_[763] = _tmp763_;
	_tmp800_[764] = _tmp764_;
	_tmp800_[765] = _tmp765_;
	_tmp800_[766] = _tmp766_;
	_tmp800_[767] = _tmp767_;
	_tmp800_[768] = _tmp768_;
	_tmp800_[769] = _tmp769_;
	_tmp800_[770] = _tmp770_;
	_tmp800_[771] = _tmp771_;
	_tmp800_[772] = _tmp772_;
	_tmp800_[773] = _tmp773_;
	_tmp800_[774] = _tmp774_;
	_tmp800_[775] = _tmp775_;
	_tmp800_[776] = _tmp776_;
	_tmp800_[777] = _tmp777_;
	_tmp800_[778] = _tmp778_;
	_tmp800_[779] = _tmp779_;
	_tmp800_[780] = _tmp780_;
	_tmp800_[781] = _tmp781_;
	_tmp800_[782] = _tmp782_;
	_tmp800_[783] = _tmp783_;
	_tmp800_[784] = _tmp784_;
	_tmp800_[785] = _tmp785_;
	_tmp800_[786] = _tmp786_;
	_tmp800_[787] = _tmp787_;
	_tmp800_[788] = _tmp788_;
	_tmp800_[789] = _tmp789_;
	_tmp800_[790] = _tmp790_;
	_tmp800_[791] = _tmp791_;
	_tmp800_[792] = _tmp792_;
	_tmp800_[793] = _tmp793_;
	_tmp800_[794] = _tmp794_;
	_tmp800_[795] = _tmp795_;
	_tmp800_[796] = _tmp796_;
	_tmp800_[797] = _tmp797_;
	_tmp800_[798] = _tmp798_;
	_tmp800_[799] = _tmp799_;
	self->languages = _tmp800_;
	self->languages_length1 = 200;
	self->languages_length2 = 4;
}

static void
scratch_dialogs_paste_bin_dialog_finalize (GObject * obj)
{
	ScratchDialogsPasteBinDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SCRATCH_DIALOGS_TYPE_PASTE_BIN_DIALOG, ScratchDialogsPasteBinDialog);
	self->languages = (_vala_array_free (self->languages, self->languages_length1 * self->languages_length2, (GDestroyNotify) g_free), NULL);
	_g_object_unref0 (self->priv->_doc);
	_g_object_unref0 (self->priv->close_button);
	_g_object_unref0 (self->priv->upload_button);
	_g_object_unref0 (self->priv->name_entry);
	_g_object_unref0 (self->priv->expiry_combo);
	_g_object_unref0 (self->priv->private_check);
	_g_object_unref0 (self->priv->format_combo);
	_g_object_unref0 (self->priv->format_dialog);
	_g_object_unref0 (self->priv->stack);
	_g_object_unref0 (self->priv->languages_listbox);
	G_OBJECT_CLASS (scratch_dialogs_paste_bin_dialog_parent_class)->finalize (obj);
}

GType
scratch_dialogs_paste_bin_dialog_get_type (void)
{
	return scratch_dialogs_paste_bin_dialog_type_id;
}

GType
scratch_dialogs_paste_bin_dialog_register_type (GTypeModule * module)
{
	static const GTypeInfo g_define_type_info = { sizeof (ScratchDialogsPasteBinDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) scratch_dialogs_paste_bin_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ScratchDialogsPasteBinDialog), 0, (GInstanceInitFunc) scratch_dialogs_paste_bin_dialog_instance_init, NULL };
	scratch_dialogs_paste_bin_dialog_type_id = g_type_module_register_type (module, GRANITE_TYPE_DIALOG, "ScratchDialogsPasteBinDialog", &g_define_type_info, G_TYPE_FLAG_NONE);
	ScratchDialogsPasteBinDialog_private_offset = sizeof (ScratchDialogsPasteBinDialogPrivate);
	return scratch_dialogs_paste_bin_dialog_type_id;
}

static void
_vala_scratch_dialogs_paste_bin_dialog_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec)
{
	ScratchDialogsPasteBinDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SCRATCH_DIALOGS_TYPE_PASTE_BIN_DIALOG, ScratchDialogsPasteBinDialog);
	switch (property_id) {
		case SCRATCH_DIALOGS_PASTE_BIN_DIALOG_DOC_PROPERTY:
		g_value_set_object (value, scratch_dialogs_paste_bin_dialog_get_doc (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_scratch_dialogs_paste_bin_dialog_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec)
{
	ScratchDialogsPasteBinDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SCRATCH_DIALOGS_TYPE_PASTE_BIN_DIALOG, ScratchDialogsPasteBinDialog);
	switch (property_id) {
		case SCRATCH_DIALOGS_PASTE_BIN_DIALOG_DOC_PROPERTY:
		scratch_dialogs_paste_bin_dialog_set_doc (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

